@@ -98,7 +98,7 @@ $Conf{UmaskMode} = 027;
 # you might have only one or two wakeups each night.  This will keep
 # the backup activity after hours.  On the other hand, if you are backing
 # up laptops that are only intermittently connected to the network you
-# will want to have frequent wakeups (eg: hourly) to maximized the chance
+# will want to have frequent wakeups (eg: hourly) to maximize the chance
 # that each laptop is backed up.
 #
 # Examples:
@@ -201,7 +201,7 @@ $Conf{MaxOldLogFiles} = 14;
 # Full path to the df command.  Security caution: normal users
 # should not allowed to write to this file or directory.
 #
-$Conf{DfPath} = '/bin/df';
+$Conf{DfPath} = '';
 
 #
 # Command to run df.  The following variables are substituted at run-time:
@@ -214,12 +214,11 @@ $Conf{DfCmd} = '$dfPath $topDir';
 #
 # Full path to various commands for archiving
 #
-
-$Conf{SplitPath} = '/usr/bin/split';
-$Conf{ParPath}   = '/usr/bin/par2';
-$Conf{CatPath}   = '/bin/cat';
-$Conf{GzipPath}  = '/bin/gzip';
-$Conf{Bzip2Path} = '/usr/bin/bzip2';
+$Conf{SplitPath} = '';
+$Conf{ParPath}   = '';
+$Conf{CatPath}   = '';
+$Conf{GzipPath}  = '';
+$Conf{Bzip2Path} = '';
 
 #
 # Maximum threshold for disk utilization on the __TOPDIR__ filesystem.
@@ -270,14 +269,27 @@ $Conf{TrashCleanSleepSec} = 300;
 $Conf{DHCPAddressRanges} = [];
 
 #
-# These configuration settings aren't used by BackupPC, but simply
-# remember a few settings used by configure.pl during installation.
-# These are used by configure.pl when upgrading to new versions of
-# BackupPC.
+# The BackupPC user.
 #
 $Conf{BackupPCUser} = '';
-$Conf{CgiDir}       = '';
-$Conf{InstallDir}   = '';
+
+#
+# Important installation directories:
+#
+#   TopDir     - where all the backup data is stored
+#   ConfDir    - where the main config and hosts files resides
+#   LogDir     - where log files and other transient information
+#   InstallDir - where the bin, lib and doc installation dirs reside.
+#                Note: you cannot change this value since all the
+#                perl scripts include this path.  You must reinstall
+#                with configure.pl to change InstallDir.
+#   CgiDir     - Apache CGI directory for BackupPC_Admin
+#
+$Conf{TopDir}      = '';
+$Conf{ConfDir}     = '';
+$Conf{LogDir}      = '';
+$Conf{InstallDir}  = '';
+$Conf{CgiDir}      = '';
 
 #
 # Whether BackupPC and the CGI script BackupPC_Admin verify that they
@@ -300,72 +312,36 @@ $Conf{BackupPCUserVerify} = 1;
 #
 $Conf{HardLinkMax} = 31999;
 
+#
+# Advanced option for asking BackupPC to load additional perl modules.
+# Can be a list (array ref) of module names to load at startup.
+#
+$Conf{PerlModuleLoad}     = undef;
+
+#
+# Path to init.d script and command to use that script to start the
+# server from the CGI interface.  The following variables are substituted
+# at run-time:
+#
+#   $sshPath           path to ssh ($Conf{SshPath})
+#   $serverHost        same as $Conf{ServerHost}
+#   $serverInitdPath   path to init.d script ($Conf{ServerInitdPath})
+#
+# Example:
+#
+# $Conf{ServerInitdPath}     = '/etc/init.d/backuppc';
+# $Conf{ServerInitdStartCmd} = '$sshPath -q -x -l root $serverHost'
+#                            . ' $serverInitdPath start'
+#                            . ' < /dev/null >& /dev/null';
+#
+$Conf{ServerInitdPath} = '';
+$Conf{ServerInitdStartCmd} = '';
+
+
 ###########################################################################
 # What to backup and when to do it
 # (can be overridden in the per-PC config.pl)
 ###########################################################################
-#
-# Name of the host share that is backed up when using SMB.  This can be a
-# string or an array of strings if there are multiple shares per host.
-# Examples:
-#
-#   $Conf{SmbShareName} = 'c';          # backup 'c' share
-#   $Conf{SmbShareName} = ['c', 'd'];   # backup 'c' and 'd' shares
-#
-# This setting only matters if $Conf{XferMethod} = 'smb'.
-#
-$Conf{SmbShareName} = 'C$';
-
-#
-# Smbclient share user name.  This is passed to smbclient's -U argument.
-#
-# This setting only matters if $Conf{XferMethod} = 'smb'.
-#
-$Conf{SmbShareUserName} = '';
-
-#
-# Smbclient share password.  This is passed to smbclient via its PASSWD
-# environment variable.  There are several ways you can tell BackupPC
-# the smb share password.  In each case you should be very careful about
-# security.  If you put the password here, make sure that this file is
-# not readable by regular users!  See the "Setting up config.pl" section
-# in the documentation for more information.
-#
-# This setting only matters if $Conf{XferMethod} = 'smb'.
-#
-$Conf{SmbSharePasswd} = '';
-
-#
-# Which host directories to backup when using tar transport.  This can be a
-# string or an array of strings if there are multiple directories to
-# backup per host.  Examples:
-#
-#   $Conf{TarShareName} = '/';			# backup everything
-#   $Conf{TarShareName} = '/home';		# only backup /home
-#   $Conf{TarShareName} = ['/home', '/src'];	# backup /home and /src
-#
-# The fact this parameter is called 'TarShareName' is for historical
-# consistency with the Smb transport options.  You can use any valid
-# directory on the client: there is no need for it to correspond to
-# any Smb share or device mount point.
-#
-# Note also that you can also use $Conf{BackupFilesOnly} to specify
-# a specific list of directories to backup.  It's more efficient to
-# use this option instead of $Conf{TarShareName} since a new tar is
-# run for each entry in $Conf{TarShareName}.
-#
-# On the other hand, if you add --one-file-system to $Conf{TarClientCmd}
-# you can backup each file system separately, which makes restoring one
-# bad file system easier.  In this case you would list all of the mount
-# points here, since you can't get the same result with
-# $Conf{BackupFilesOnly}:
-#
-#     $Conf{TarShareName} = ['/', '/var', '/data', '/boot'];
-#
-# This setting only matters if $Conf{XferMethod} = 'tar'.
-#
-$Conf{TarShareName} = '/';
-
 #
 # Minimum period in days between full backups. A full dump will only be
 # done if at least this much time has elapsed since the last full dump,
@@ -376,18 +352,6 @@ $Conf{TarShareName} = '/';
 # time taken for the backup, plus the granularity of $Conf{WakeupSchedule}
 # will make the actual backup interval a bit longer.
 #
-# There are two special values for $Conf{FullPeriod}:
-#
-#   -1   Don't do any regular backups on this machine.  Manually
-#        requested backups (via the CGI interface) will still occur.
-#
-#   -2   Don't do any backups on this machine.  Manually requested
-#        backups (via the CGI interface) will be ignored.
-#
-# These special settings are useful for a client that is no longer
-# being backed up (eg: a retired machine), but you wish to keep the
-# last backups available for browsing or restoring to other machines.
-#
 $Conf{FullPeriod} = 6.97;
 
 #
@@ -480,8 +444,8 @@ $Conf{FullKeepCnt} = 1;
 # we keep at least $Conf{FullKeepCntMin} full backups no matter how old
 # they are.
 #
-# Note that $Conf{FullAgeMax} will be increased to $Conf{FullAgeMax}
-# times $Conf{FullPeriod} if $Conf{FullAgeMax} specifies enough
+# Note that $Conf{FullAgeMax} will be increased to $Conf{FullKeepCnt}
+# times $Conf{FullPeriod} if $Conf{FullKeepCnt} specifies enough
 # full backups to exceed $Conf{FullAgeMax}.
 #
 $Conf{FullKeepCntMin} = 1;
@@ -504,6 +468,105 @@ $Conf{IncrKeepCnt} = 6;
 $Conf{IncrKeepCntMin} = 1;
 $Conf{IncrAgeMax}     = 30;
 
+#
+# Level of each incremental.  "Level" follows the terminology
+# of dump(1).  A full backup has level 0.  A new incremental
+# of level N will backup all files that have changed since
+# the most recent backup of a lower level.
+#
+# The entries of $Conf{IncrLevels} apply in order to each
+# incremental after each full backup.  It wraps around until
+# the next full backup.  For example, these two settings
+# have the same effect:
+#
+#       $Conf{IncrLevels} = [1, 2, 3];
+#       $Conf{IncrLevels} = [1, 2, 3, 1, 2, 3];
+#
+# This means the 1st and 4th incrementals (level 1) go all
+# the way back to the full.  The 2nd and 3rd (and 5th and
+# 6th) backups just go back to the immediate preceeding
+# incremental.
+#
+# Specifying a sequence of multi-level incrementals will
+# usually mean more than $Conf{IncrKeepCnt} incrementals will
+# need to be kept, since lower level incrementals are needed
+# to merge a complete view of a backup.  For example, with
+#
+#       $Conf{FullPeriod}  = 7;
+#       $Conf{IncrPeriod}  = 1;
+#       $Conf{IncrKeepCnt} = 6;
+#       $Conf{IncrLevels}  = [1, 2, 3, 4, 5, 6];
+#
+# there will be up to 11 incrementals in this case: 
+#
+#       backup #0  (full, level 0, oldest)
+#       backup #1  (incr, level 1)
+#       backup #2  (incr, level 2)
+#       backup #3  (incr, level 3)
+#       backup #4  (incr, level 4)
+#       backup #5  (incr, level 5)
+#       backup #6  (incr, level 6)
+#       backup #7  (full, level 0)
+#       backup #8  (incr, level 1)
+#       backup #9  (incr, level 2)
+#       backup #10 (incr, level 3)
+#       backup #11 (incr, level 4)
+#       backup #12 (incr, level 5, newest)
+#
+# Backup #1 (the oldest level 1 incremental) can't be deleted
+# since backups 2..6 depend on it.  Those 6 incrementals can't
+# all be deleted since that would only leave 5 (#8..12).
+# When the next incremental happens (level 6), the complete
+# set of 6 older incrementals (#1..6) will be deleted, since
+# that maintains the required number ($Conf{IncrKeepCnt})
+# of incrementals.  This situation is reduced if you set
+# shorter chains of multi-level incrementals, eg:
+#
+#       $Conf{IncrLevels}  = [1, 2, 3];
+#
+# would only have up to 2 extra incremenals before all 3
+# are deleted.
+#
+# BackupPC as usual merges the full and the sequence
+# of incrementals together so each incremental can be
+# browsed and restored as though it is a complete backup.
+# If you specify a long chain of incrementals then more
+# backups need to be merged when browsing, restoring,
+# or getting the starting point for rsync backups.
+# In the example above (levels 1..6), browing backup
+# #6 requires 7 different backups (#0..6) to be merged.
+#
+# Because of this merging and the additional incrementals
+# that need to be kept, it is recommended that some
+# level 1 incrementals be included in $Conf{IncrLevels}.
+#
+# Prior to version 3.0 incrementals were always level 1,
+# meaning each incremental backed up all the files that
+# changed since the last full.
+#
+$Conf{IncrLevels} = [1];
+
+#
+# Disable all full and incremental backups.  These settings are
+# useful for a client that is no longer being backed up
+# (eg: a retired machine), but you wish to keep the last
+# backups available for browsing or restoring to other machines.
+#
+# There are three values for $Conf{BackupsDisable}:
+#
+#   0    Backups are enabled.
+#
+#   1    Don't do any regular backups on this client.  Manually
+#        requested backups (via the CGI interface) will still occur.
+#
+#   2    Don't do any backups on this client.  Manually requested
+#        backups (via the CGI interface) will be ignored.
+#
+# In versions prior to 3.0 Backups were disabled by setting
+# $Conf{FullPeriod} to -1 or -2.
+#
+$Conf{BackupsDisable} = 0;
+
 #
 # A failed full backup is saved as a partial backup.  The rsync
 # XferMethod can take advantage of the partial full when the next
@@ -583,6 +646,9 @@ $Conf{ArchiveInfoKeepCnt} = 10;
 # array, and $Conf{SmbShareName} contains multiple share names, then
 # the setting is assumed to apply all shares.
 #
+# If a hash is used, a special key "*" means it applies to all
+# shares that don't have a specific entry.
+#
 # Examples:
 #    $Conf{BackupFilesOnly} = '/myFiles';
 #    $Conf{BackupFilesOnly} = ['/myFiles'];     # same as first example
@@ -591,6 +657,10 @@ $Conf{ArchiveInfoKeepCnt} = 10;
 #       'c' => ['/myFiles', '/important'],      # these are for 'c' share
 #       'd' => ['/moreFiles', '/archive'],      # these are for 'd' share
 #    };
+#    $Conf{BackupFilesOnly} = {
+#       'c' => ['/myFiles', '/important'],      # these are for 'c' share
+#       '*' => ['/myFiles', '/important'],      # these are other shares
+#    };
 #
 $Conf{BackupFilesOnly} = undef;
 
@@ -626,6 +696,9 @@ $Conf{BackupFilesOnly} = undef;
 # Users report that for smbclient you should specify a directory
 # followed by "/*", eg: "/proc/*", instead of just "/proc".
 #
+# If a hash is used, a special key "*" means it applies to all
+# shares that don't have a specific entry.
+#
 # Examples:
 #    $Conf{BackupFilesExclude} = '/temp';
 #    $Conf{BackupFilesExclude} = ['/temp'];     # same as first example
@@ -634,6 +707,10 @@ $Conf{BackupFilesOnly} = undef;
 #       'c' => ['/temp', '/winnt/tmp'],         # these are for 'c' share
 #       'd' => ['/junk', '/dont_back_this_up'], # these are for 'd' share
 #    };
+#    $Conf{BackupFilesExclude} = {
+#       'c' => ['/temp', '/winnt/tmp'],         # these are for 'c' share
+#       '*' => ['/junk', '/dont_back_this_up'], # these are for other shares
+#    };
 #
 $Conf{BackupFilesExclude} = undef;
 
@@ -725,7 +802,7 @@ $Conf{BlackoutPeriods} = [
 $Conf{BackupZeroFilesIsFatal} = 1;
 
 ###########################################################################
-# General per-PC configuration settings
+# How to backup a client
 # (can be overridden in the per-PC config.pl)
 ###########################################################################
 #
@@ -762,6 +839,68 @@ $Conf{XferMethod} = 'smb';
 #
 $Conf{XferLogLevel} = 1;
 
+#
+# Filename charset encoding on the client.  BackupPC uses utf8
+# on the server for filename encoding.  If this is empty, then
+# utf8 is assumed and client filenames will not be modified.
+# If set to a different encoding then filenames will converted
+# to/from utf8 automatically during backup and restore.
+#
+# If the file names displayed in the browser (eg: accents or special
+# characters) don't look right then it is likely you haven't set
+# $Conf{ClientCharset} correctly.
+#
+# If you are using smbclient on a WinXX machine, smbclient will convert
+# to the "unix charset" setting in smb.conf.  The default is utf8,
+# in which case leave $Conf{ClientCharset} empty since smbclient does
+# the right conversion.
+#
+# If you are using rsync on a WinXX machine then it does no conversion.
+# A typical WinXX encoding for latin1/western europe is 'cp1252',
+# so in this case set $Conf{ClientCharset} to 'cp1252'.
+#
+# On a linux or unix client, run "locale charmap" to see the client's
+# charset.  Set $Conf{ClientCharset} to this value.  A typical value
+# for english/US is 'ISO-8859-1'.
+#
+# Do "perldoc Encode::Supported" to see the list of possible charset
+# values.  The FAQ at http://www.cl.cam.ac.uk/~mgk25/unicode.html
+# is excellent, and http://czyborra.com/charsets/iso8859.html
+# provides more information on the iso-8859 charsets.
+#
+$Conf{ClientCharset} = '';
+
+#
+# Name of the host share that is backed up when using SMB.  This can be a
+# string or an array of strings if there are multiple shares per host.
+# Examples:
+#
+#   $Conf{SmbShareName} = 'c';          # backup 'c' share
+#   $Conf{SmbShareName} = ['c', 'd'];   # backup 'c' and 'd' shares
+#
+# This setting only matters if $Conf{XferMethod} = 'smb'.
+#
+$Conf{SmbShareName} = 'C$';
+
+#
+# Smbclient share user name.  This is passed to smbclient's -U argument.
+#
+# This setting only matters if $Conf{XferMethod} = 'smb'.
+#
+$Conf{SmbShareUserName} = '';
+
+#
+# Smbclient share password.  This is passed to smbclient via its PASSWD
+# environment variable.  There are several ways you can tell BackupPC
+# the smb share password.  In each case you should be very careful about
+# security.  If you put the password here, make sure that this file is
+# not readable by regular users!  See the "Setting up config.pl" section
+# in the documentation for more information.
+#
+# This setting only matters if $Conf{XferMethod} = 'smb'.
+#
+$Conf{SmbSharePasswd} = '';
+
 #
 # Full path for smbclient. Security caution: normal users should not
 # allowed to write to this file or directory.
@@ -772,7 +911,7 @@ $Conf{XferLogLevel} = 1;
 #
 # This setting only matters if $Conf{XferMethod} = 'smb'.
 #
-$Conf{SmbClientPath} = '/usr/bin/smbclient';
+$Conf{SmbClientPath} = '';
 
 #
 # Command to run smbclient for a full dump.
@@ -818,6 +957,37 @@ $Conf{SmbClientRestoreCmd} = '$smbClientPath \\\\$host\\$shareName'
             . ' $I_option -U $userName -E -N -d 1'
             . ' -c tarmode\\ full -Tx -';
 
+#
+# Which host directories to backup when using tar transport.  This can be a
+# string or an array of strings if there are multiple directories to
+# backup per host.  Examples:
+#
+#   $Conf{TarShareName} = '/';			# backup everything
+#   $Conf{TarShareName} = '/home';		# only backup /home
+#   $Conf{TarShareName} = ['/home', '/src'];	# backup /home and /src
+#
+# The fact this parameter is called 'TarShareName' is for historical
+# consistency with the Smb transport options.  You can use any valid
+# directory on the client: there is no need for it to correspond to
+# any Smb share or device mount point.
+#
+# Note also that you can also use $Conf{BackupFilesOnly} to specify
+# a specific list of directories to backup.  It's more efficient to
+# use this option instead of $Conf{TarShareName} since a new tar is
+# run for each entry in $Conf{TarShareName}.
+#
+# On the other hand, if you add --one-file-system to $Conf{TarClientCmd}
+# you can backup each file system separately, which makes restoring one
+# bad file system easier.  In this case you would list all of the mount
+# points here, since you can't get the same result with
+# $Conf{BackupFilesOnly}:
+#
+#     $Conf{TarShareName} = ['/', '/var', '/data', '/boot'];
+#
+# This setting only matters if $Conf{XferMethod} = 'tar'.
+#
+$Conf{TarShareName} = '/';
+
 #
 # Full command to run tar on the client.  GNU tar is required.  You will
 # need to fill in the correct paths for ssh2 on the local host (server)
@@ -854,7 +1024,7 @@ $Conf{SmbClientRestoreCmd} = '$smbClientPath \\\\$host\\$shareName'
 # This setting only matters if $Conf{XferMethod} = 'tar'.
 #
 $Conf{TarClientCmd} = '$sshPath -q -x -n -l root $host'
-                    . ' $tarPath -c -v -f - -C $shareName+'
+                    . ' env LC_ALL=C $tarPath -c -v -f - -C $shareName+'
                     . ' --totals';
 
 #
@@ -911,7 +1081,7 @@ $Conf{TarIncrArgs} = '--newer=$incrDate+ $fileList+';
 # restore option will be removed.
 #
 $Conf{TarClientRestoreCmd} = '$sshPath -q -x -l root $host'
-		   . ' $tarPath -x -p --numeric-owner --same-owner'
+		   . ' env LC_ALL=C $tarPath -x -p --numeric-owner --same-owner'
 		   . ' -v -f - -C $shareName+';
 
 #
@@ -920,12 +1090,12 @@ $Conf{TarClientRestoreCmd} = '$sshPath -q -x -l root $host'
 #
 # This setting only matters if $Conf{XferMethod} = 'tar'.
 #
-$Conf{TarClientPath} = '/bin/tar';
+$Conf{TarClientPath} = '';
 
 #
 # Path to rsync executable on the client
 #
-$Conf{RsyncClientPath} = '/bin/rsync';
+$Conf{RsyncClientPath} = '';
 
 #
 # Full command to run rsync on the client machine.  The following variables
@@ -1010,7 +1180,7 @@ $Conf{RsyncdAuthRequired} = 1;
 #
 # When rsync checksum caching is enabled (by adding the
 # --checksum-seed=32761 option to $Conf{RsyncArgs}), the cached
-# checksums can be occaisonally verified to make sure the file
+# checksums can be occasionally verified to make sure the file
 # contents matches the cached checksums.  This is to avoid the
 # risk that disk problems might cause the pool file contents to
 # get corrupted, but the cached checksums would make BackupPC
@@ -1052,16 +1222,19 @@ $Conf{RsyncArgs} = [
             '--perms',
             '--owner',
             '--group',
-            '--devices',
+            '-D',
             '--links',
+            '--hard-links',
             '--times',
             '--block-size=2048',
             '--recursive',
 
 	    #
-	    # If you are using a patched client rsync that supports the
-	    # --checksum-seed option (see http://backuppc.sourceforge.net),
-	    # then uncomment this to enabled rsync checksum cachcing
+	    # Rsync >= 2.6.3 supports the --checksum-seed option
+            # which allows rsync checksum caching on the server.
+	    # Uncomment this to enable rsync checksum caching if
+            # you have a recent client rsync version and you want
+            # to enable checksum caching.
 	    #
 	    #'--checksum-seed=32761',
 
@@ -1086,8 +1259,9 @@ $Conf{RsyncRestoreArgs} = [
 	    '--perms',
 	    '--owner',
 	    '--group',
-	    '--devices',
+	    '-D',
 	    '--links',
+            '--hard-links',
 	    '--times',
 	    '--block-size=2048',
 	    '--relative',
@@ -1095,9 +1269,11 @@ $Conf{RsyncRestoreArgs} = [
 	    '--recursive',
 
 	    #
-	    # If you are using a patched client rsync that supports the
-	    # --checksum-seed option (see http://backuppc.sourceforge.net),
-	    # then uncomment this to enabled rsync checksum cachcing
+	    # Rsync >= 2.6.3 supports the --checksum-seed option
+            # which allows rsync checksum caching on the server.
+	    # Uncomment this to enable rsync checksum caching if
+            # you have a recent client rsync version and you want
+            # to enable checksum caching.
 	    #
 	    #'--checksum-seed=32761',
 
@@ -1106,6 +1282,63 @@ $Conf{RsyncRestoreArgs} = [
 	    #
 ];
 
+#
+# Share name to backup.  For $Conf{XferMethod} = "backuppcd" this should
+# be a file system path, eg '/' or '/home'.
+#
+# This can also be a list of multiple file system paths or modules.
+# (Can it??)
+#
+#     $Conf{BackupPCdShareName} = ['/', '/var', '/data', '/boot'];
+#
+$Conf{BackupPCdShareName} = '/';
+
+#
+# Path to backuppcd executable on the server
+#
+$Conf{BackupPCdPath} = '';
+
+#
+# Full command to run backuppcd on the server to backup a given
+# client machine.  The following variables are substituted at
+# run-time (TODO: update this list)
+#
+#        $host           host name being backed up
+#        $hostIP         host's IP address
+#        $shareName      share name to backup (ie: top-level directory path)
+#        $backuppcdPath  same as $Conf{BackupPCdPath}
+#        $sshPath        same as $Conf{SshPath}
+#
+# This setting only matters if $Conf{XferMethod} = 'backuppcd'.
+#
+# Arguments to backupcpd are:
+#
+#   - the host name to backup
+#   - the share name to backup
+#   - the directory where the pool is
+#   - the directory where the last run was (NOT DONE YET)
+#   - a boolean value indicating whether or not the pool is
+#      compressed or not
+#   - the directory where the new run should occur (currently it assumes ".")
+#
+$Conf{BackupPCdCmd} = '$bpcdPath $host $shareName $poolDir XXXX $poolCompress $topDir/pc/$client/new';
+
+#
+# Full command to run backuppcd on the server for restore to a
+# client machine.  The following variables are substituted at
+# run-time (TODO: update this list)
+#
+#        $host           host name being backed up
+#        $hostIP         host's IP address
+#        $shareName      share name to backup (ie: top-level directory path)
+#        $backuppcdPath  same as $Conf{BackupPCdPath}
+#        $sshPath        same as $Conf{SshPath}
+#
+# This setting only matters if $Conf{XferMethod} = 'backuppcd'.
+#
+$Conf{BackupPCdRestoreCmd} = '$bpcdPath TODO';
+
+
 #
 # Archive Destination
 #
@@ -1179,7 +1412,7 @@ $Conf{ArchiveClientCmd} = '$Installdir/bin/BackupPC_archiveHost'
 # Full path for ssh. Security caution: normal users should not
 # allowed to write to this file or directory.
 #
-$Conf{SshPath} = '/usr/bin/ssh';
+$Conf{SshPath} = '';
 
 #
 # Full path for nmblookup. Security caution: normal users should not
@@ -1188,7 +1421,7 @@ $Conf{SshPath} = '/usr/bin/ssh';
 # nmblookup is from the Samba distribution. nmblookup is used to get the
 # netbios name, necessary for DHCP hosts.
 #
-$Conf{NmbLookupPath} = '/usr/bin/nmblookup';
+$Conf{NmbLookupPath} = '';
 
 #
 # NmbLookup command.  Given an IP address, does an nmblookup on that
@@ -1248,7 +1481,7 @@ $Conf{FixedIPNetBiosNameCheck} = 0;
 #
 #     $Conf{PingPath} = '/bin/echo';
 #
-$Conf{PingPath} = '/bin/ping';
+$Conf{PingPath} = '';
 
 #
 # Ping command.  The following variables are substituted at run-time:
@@ -1263,23 +1496,15 @@ $Conf{PingPath} = '/bin/ping';
 $Conf{PingCmd} = '$pingPath -c 1 $host';
 
 #
-# Path to init.d script and command to use that script to start the
-# server from the CGI interface.  The following variables are substituted
-# at run-time:
+# Maximum round-trip ping time in milliseconds.  This threshold is set
+# to avoid backing up PCs that are remotely connected through WAN or
+# dialup connections.  The output from ping -s (assuming it is supported
+# on your system) is used to check the round-trip packet time.  On your
+# local LAN round-trip times should be much less than 20msec.  On most
+# WAN or dialup connections the round-trip time will be typically more
+# than 20msec.  Tune if necessary.
 #
-#   $sshPath           path to ssh ($Conf{SshPath})
-#   $serverHost        same as $Conf{ServerHost}
-#   $serverInitdPath   path to init.d script ($Conf{ServerInitdPath})
-#
-# Example:
-#
-# $Conf{ServerInitdPath}     = '/etc/init.d/backuppc';
-# $Conf{ServerInitdStartCmd} = '$sshPath -q -x -l root $serverHost'
-#                            . ' $serverInitdPath start'
-#                            . ' < /dev/null >& /dev/null';
-#
-$Conf{ServerInitdPath} = '';
-$Conf{ServerInitdStartCmd} = '';
+$Conf{PingMaxMsec} = 20;
 
 #
 # Compression level to use on files.  0 means no compression.  Compression
@@ -1312,17 +1537,6 @@ $Conf{ServerInitdStartCmd} = '';
 #
 $Conf{CompressLevel} = 0;
 
-#
-# Maximum round-trip ping time in milliseconds.  This threshold is set
-# to avoid backing up PCs that are remotely connected through WAN or
-# dialup connections.  The output from ping -s (assuming it is supported
-# on your system) is used to check the round-trip packet time.  On your
-# local LAN round-trip times should be much less than 20msec.  On most
-# WAN or dialup connections the round-trip time will be typically more
-# than 20msec.  Tune if necessary.
-#
-$Conf{PingMaxMsec} = 20;
-
 #
 # Timeout in seconds when listening for the transport program's
 # (smbclient, tar etc) stdout. If no output is received during this
@@ -1353,16 +1567,20 @@ $Conf{ClientTimeout} = 72000;
 $Conf{MaxOldPerPCLogFiles} = 12;
 
 #
-# Optional commands to run before and after dumps and restores.
+# Optional commands to run before and after dumps and restores,
+# and also before and after each share of a dump.
+#
 # Stdout from these commands will be written to the Xfer (or Restore)
 # log file.  One example of using these commands would be to
-# shut down and restart a database server, or to dump a database
-# to files for backup.  Example:
+# shut down and restart a database server, dump a database
+# to files for backup, or doing a snapshot of a share prior
+# to a backup.  Example:
 #
 #    $Conf{DumpPreUserCmd} = '$sshPath -q -x -l root $host /usr/bin/dumpMysql';
 #
 # The following variable substitutions are made at run time for
-# $Conf{DumpPreUserCmd} and $Conf{DumpPostUserCmd}:
+# $Conf{DumpPreUserCmd}, $Conf{DumpPostUserCmd}, $Conf{DumpPreShareCmd}
+# and $Conf{DumpPostShareCmd}:
 #
 #        $type         type of dump (incr or full)
 #        $xferOK       1 if the dump succeeded, 0 if it didn't
@@ -1372,7 +1590,8 @@ $Conf{MaxOldPerPCLogFiles} = 12;
 #        $hostIP       IP address of host
 #        $user         user name from the hosts file
 #        $moreUsers    list of additional users from the hosts file
-#        $share        the first share name
+#        $share        the first share name (or current share for
+#                        $Conf{DumpPreShareCmd} and $Conf{DumpPostShareCmd})
 #        $shares       list of all the share names
 #        $XferMethod   value of $Conf{XferMethod} (eg: tar, rsync, smb)
 #        $sshPath      value of $Conf{SshPath},
@@ -1422,11 +1641,36 @@ $Conf{MaxOldPerPCLogFiles} = 12;
 #
 $Conf{DumpPreUserCmd}     = undef;
 $Conf{DumpPostUserCmd}    = undef;
+$Conf{DumpPreShareCmd}    = undef;
+$Conf{DumpPostShareCmd}   = undef;
 $Conf{RestorePreUserCmd}  = undef;
 $Conf{RestorePostUserCmd} = undef;
 $Conf{ArchivePreUserCmd}  = undef;
 $Conf{ArchivePostUserCmd} = undef;
 
+#
+# Whether the exit status of each PreUserCmd and
+# PostUserCmd is checked.
+#
+# If set and the Dump/Restore/Archive Pre/Post UserCmd
+# returns a non-zero exit status then the dump/restore/archive
+# is aborted.  To maintain backward compatibility (where
+# the exit status in early versions was always ignored),
+# this flag defaults to 0.
+#
+# If this flag is set and the Dump/Restore/Archive PreUserCmd
+# fails then the matching Dump/Restore/Archive PostUserCmd is
+# not executed.  If DumpPreShareCmd returns a non-exit status,
+# then DumpPostShareCmd is not executed, but the DumpPostUserCmd
+# is still run (since DumpPreUserCmd must have previously
+# succeeded).
+#
+# An example of a DumpPreUserCmd that might fail is a script
+# that snapshots or dumps a database which fails because
+# of some database error.
+#
+$Conf{UserCmdCheckStatus} = 0;
+
 #
 # Override the client's host name.  This allows multiple clients
 # to all refer to the same physical host.  This should only be
@@ -1446,12 +1690,6 @@ $Conf{ArchivePostUserCmd} = undef;
 #
 $Conf{ClientNameAlias} = undef;
 
-#
-# Advanced option for asking BackupPC to load additional perl modules.
-# Can be a list (array ref) of module names to load at startup.
-#
-$Conf{PerlModuleLoad}     = undef;
-
 ###########################################################################
 # Email reminders, status and messages
 # (can be overridden in the per-PC config.pl)
@@ -1460,7 +1698,7 @@ $Conf{PerlModuleLoad}     = undef;
 # Full path to the sendmail command.  Security caution: normal users
 # should not allowed to write to this file or directory.
 #
-$Conf{SendmailPath} = '/usr/sbin/sendmail';
+$Conf{SendmailPath} = '';
 
 #
 # Minimum period between consecutive emails to a single user.
@@ -1510,7 +1748,7 @@ $Conf{EMailUserDestDomain} = '';
 #   To: $user$domain
 #   cc:
 #   Subject: $subj
-#   $headers
+#   
 #   Dear $userName,
 #   
 #   This is a site-specific email message.
@@ -1538,7 +1776,7 @@ $Conf{EMailNotifyOldBackupDays} = 7.0;
 #   To: $user$domain
 #   cc:
 #   Subject: $subj
-#   $headers
+#   
 #   Dear $userName,
 #   
 #   This is a site-specific email message.
@@ -1566,7 +1804,7 @@ $Conf{EMailNotifyOldOutlookDays} = 5.0;
 #   To: $user$domain
 #   cc:
 #   Subject: $subj
-#   $headers
+#   
 #   Dear $userName,
 #   
 #   This is a site-specific email message.
@@ -1575,6 +1813,16 @@ $Conf{EMailNotifyOldOutlookDays} = 5.0;
 $Conf{EMailOutlookBackupSubj} = undef;
 $Conf{EMailOutlookBackupMesg} = undef;
 
+#
+# Additional email headers.  If you change the charset
+# to utf8 then BackupPC_sendEmail will use utf8 for
+# the email body.
+#
+$Conf{EMailHeaders} = <<EOF;
+MIME-Version: 1.0
+Content-Type: text/plain; charset="iso-8859-1"
+EOF
+
 ###########################################################################
 # CGI user interface configuration settings
 # (can be overridden in the per-PC config.pl)
@@ -1616,7 +1864,8 @@ $Conf{CgiURL} = undef;
 #   
 # Language to use.  See lib/BackupPC/Lang for the list of supported
 # languages, which include English (en), French (fr), Spanish (es),
-# German (de), Italian (it) and Dutch (nl).
+# German (de), Italian (it), Dutch (nl) and Portuguese Brazillian
+# (pt_br).
 #
 # Currently the Language setting applies to the CGI interface and email
 # messages sent to users.  Log files and other text are still in English.
@@ -1697,6 +1946,8 @@ $Conf{CgiStatusHilightColor} = {
     Reason_no_ping                 => '#ffff99',
     Reason_backup_canceled_by_user => '#ff9900',
     Status_backup_in_progress      => '#66cc99',
+    Disabled_OnlyManualBackups     => '#d1d1d1',   
+    Disabled_AllBackupsDisabled    => '#d1d1d1',          
 };
 
 #
@@ -1736,8 +1987,112 @@ $Conf{CgiExt2ContentType} = { };
 $Conf{CgiImageDirURL} = '';
 
 #
-# CSS stylesheet for the CGI interface.  It is stored in the
-# $Conf{CgiImageDir} directory and accessed via the
+# CSS stylesheet "skin" for the CGI interface.  It is stored
+# in the $Conf{CgiImageDir} directory and accessed via the
 # $Conf{CgiImageDirURL} URL.
 #
+# For BackupPC v3.x several color, layout and font changes were made.
+# The previous v2.x version is available as BackupPC_stnd_orig.css, so
+# if you prefer the old skin, change this to BackupPC_stnd_orig.css.
+#
 $Conf{CgiCSSFile} = 'BackupPC_stnd.css';
+
+#
+# Whether the user is allowed to edit their per-PC config.
+#
+$Conf{CgiUserConfigEditEnable} = 1;
+
+#
+# Which per-host config variables a non-admin user is allowed
+# to edit.  Admin users can edit all per-host config variables,
+# even if disabled in this list.
+#
+# SECURITY WARNING: Do not let users edit any of the Cmd
+# config variables!  That's because a user could set a
+# Cmd to a shell script of their choice and it will be
+# run as the BackupPC user.  That script could do all
+# sorts of bad things.
+#
+$Conf{CgiUserConfigEdit} = {
+        FullPeriod                => 1,
+        IncrPeriod                => 1,
+        FullKeepCnt               => 1,
+        FullKeepCntMin            => 1,
+        FullAgeMax                => 1,
+        IncrKeepCnt               => 1,
+        IncrKeepCntMin            => 1,
+        IncrAgeMax                => 1,
+        IncrLevels                => 1,
+        IncrFill                  => 1,
+        PartialAgeMax             => 1,
+        RestoreInfoKeepCnt        => 1,
+        ArchiveInfoKeepCnt        => 1,
+        BackupFilesOnly           => 1,
+        BackupFilesExclude        => 1,
+        BackupsDisable            => 1,
+        BlackoutBadPingLimit      => 1,
+        BlackoutGoodCnt           => 1,
+        BlackoutPeriods           => 1,
+        BackupZeroFilesIsFatal    => 1,
+        ClientCharset             => 1,
+        XferMethod                => 1,
+        XferLogLevel              => 1,
+        SmbShareName              => 1,
+        SmbShareUserName          => 1,
+        SmbSharePasswd            => 1,
+        SmbClientFullCmd          => 0,
+        SmbClientIncrCmd          => 0,
+        SmbClientRestoreCmd       => 0,
+        TarShareName              => 1,
+        TarFullArgs               => 1,
+        TarIncrArgs               => 1,
+        TarClientCmd              => 0,
+        TarClientRestoreCmd       => 0,
+        TarClientPath             => 0,
+        RsyncShareName            => 1,
+        RsyncdClientPort          => 1,
+        RsyncdPasswd              => 1,
+        RsyncdAuthRequired        => 1,
+        RsyncCsumCacheVerifyProb  => 1,
+        RsyncArgs                 => 1,
+        RsyncRestoreArgs          => 1,
+        RsyncClientCmd            => 0,
+        RsyncClientRestoreCmd     => 0,
+        RsyncClientPath           => 0,
+        ArchiveDest               => 1,
+        ArchiveComp               => 1,
+        ArchivePar                => 1,
+        ArchiveSplit              => 1,
+        ArchiveClientCmd          => 0,
+        FixedIPNetBiosNameCheck   => 1,
+        NmbLookupCmd              => 0,
+        NmbLookupFindHostCmd      => 0,
+        PingMaxMsec               => 1,
+        PingCmd                   => 0,
+        ClientTimeout             => 1,
+        MaxOldPerPCLogFiles       => 1,
+        CompressLevel             => 1,
+        ClientNameAlias           => 1,
+        DumpPreUserCmd            => 0,
+        DumpPostUserCmd           => 0,
+        RestorePreUserCmd         => 0,
+        RestorePostUserCmd        => 0,
+        ArchivePreUserCmd         => 0,
+        ArchivePostUserCmd        => 0,
+        DumpPostShareCmd          => 0,
+        DumpPreShareCmd           => 0,
+        UserCmdCheckStatus        => 0,
+        EMailNotifyMinDays        => 1,
+        EMailFromUserName         => 1,
+        EMailAdminUserName        => 1,
+        EMailUserDestDomain       => 1,
+        EMailNoBackupEverSubj     => 1,
+        EMailNoBackupEverMesg     => 1,
+        EMailNotifyOldBackupDays  => 1,
+        EMailNoBackupRecentSubj   => 1,
+        EMailNoBackupRecentMesg   => 1,
+        EMailNotifyOldOutlookDays => 1,
+        EMailOutlookBackupSubj    => 1,
+        EMailOutlookBackupMesg    => 1,
+        EMailHeaders              => 1,
+};
