@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 2.1.2, released 5 Sep 2005.
+# Version 3.0.0, released 28 Jan 2007.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -43,9 +43,9 @@ sub action
 {
     my($str, $reply);
 
-    my $start = 1 if ( $In{action} eq $Lang->{Start_Incr_Backup}
-                       || $In{action} eq $Lang->{Start_Full_Backup} );
-    my $doFull = $In{action} eq $Lang->{Start_Full_Backup} ? 1 : 0;
+    my $start = 1 if ( $In{action} eq "Start_Incr_Backup"
+                       || $In{action} eq "Start_Full_Backup" );
+    my $doFull = $In{action} eq "Start_Full_Backup" ? 1 : 0;
     my $type = $doFull ? $Lang->{Type_full} : $Lang->{Type_incr};
     my $host = $In{host};
     my $Privileged = CheckPermission($host);
@@ -76,7 +76,14 @@ sub action
         Trailer();
     } else {
         if ( $start ) {
-	    my $ipAddr = ConfirmIPAddress($host);
+            $bpc->ConfigRead($host);
+            %Conf = $bpc->Conf();
+
+            my $checkHost = $host;
+            $checkHost = $Conf{ClientNameAlias}
+                                if ( $Conf{ClientNameAlias} ne "" );
+	    my $ipAddr     = ConfirmIPAddress($checkHost);
+            my $buttonText = $Lang->{$In{action}};
 	    my $content = eval("qq{$Lang->{Are_you_sure_start}}");
             Header(eval("qq{$Lang->{BackupPC__Start_Backup_Confirm_on__host}}"),$content);
         } else {
@@ -86,6 +93,7 @@ sub action
                 $backoff = sprintf("%.1f",
                                   ($StatusHost{backoffTime} - time) / 3600);
             }
+            my $buttonText = $Lang->{$In{action}};
             my $content = eval ("qq{$Lang->{Are_you_sure_stop}}");
             Header(eval("qq{$Lang->{BackupPC__Stop_Backup_Confirm_on__host}}"),
                         $content);
