@@ -1,5 +1,7 @@
 #!/bin/perl
 #
+# by Ralph Passgang <ralph@debianbase.de> (13.11.2006 for V3.0.0)
+# by Ralph Passgang <ralph@debianbase.de> (30.06.2006 for V3.0.0)
 # by Ralph Passgang <ralph@debianbase.de> (07.06.2004 for V2.1.0beta3)
 # by Ralph Passgang <ralph@debianbase.de> (06.05.2004 for V2.1.0beta2)
 # by Manfred Herrmann (11.03.2004 for V2.1.0beta0)
@@ -24,33 +26,35 @@ $Lang{Type_incr} = "inkrementell";
 
 # -----
 
-$Lang{Only_privileged_users_can_view_admin_options} = "Nur privilegierte Nutzer knnen die Administrator Optionen einsehen.";
+$Lang{Only_privileged_users_can_view_admin_options} = "Nur privilegierte Nutzer knnen die Administrationsoptionen einsehen.";
 $Lang{H_Admin_Options} = "BackupPC: Server Administrationsoptionen";
 $Lang{Admin_Options} = "Admin Optionen";
 $Lang{Admin_Options_Page} = <<EOF;
 \${h1(qq{$Lang{Admin_Options}})}
 <br>
 \${h2("Server Steuerung")}
-<form action="\$MyURL" method="get">
+<form name="ReloadForm" action="\$MyURL" method="get">
+<input type="hidden" name="action" value="">
 <table class="tableStnd">
-  <!--<tr><td>Server stoppen:<td><input type="submit" name="action" value="Stop">-->
-  <tr><td>Server Konfiguration neu laden:<td><input type="submit" name="action" value="Reload">
+  <tr><td>Server Konfiguration neu laden:<td><input type="button" value="Reload"
+     onClick="document.ReloadForm.action.value='Reload';
+              document.ReloadForm.submit();">
 </table>
 </form>
 <!--
 \${h2("Server Konfiguration")}
 <ul>
-  <li><i>Andere Optionen sind hier mglich ... z.B.,</i>
-  <li>Server Konfiguration editieren
+  <li><i>Andere Optionen sind hier mglich ... z.B.</i>
+  <li>Serverkonfiguration editieren
 </ul>
 -->
 EOF
 $Lang{Unable_to_connect_to_BackupPC_server} = "Kann keine Verbindung zu dem BackupPC Server herstellen!",
             "Dieses CGI Script (\$MyURL) kann keine Verbindung zu dem BackupPC"
-          . " Server auf \$Conf{ServerHost} Port \$Conf{ServerPort} herstellen.  Der Fehler"
+          . " Server auf \$Conf{ServerHost} Port \$Conf{ServerPort} herstellen. Der Fehler"
           . " war: \$err.",
             "Mglicherweise ist der BackupPC Server Prozess nicht gestartet oder es besteht ein"
-          . " Konfigurationsfehler.  Bitte teilen Sie diese Fehlermeldung dem Systemadministrator mit.";
+          . " Konfigurationsfehler. Bitte teilen Sie diese Fehlermeldung dem Systemadministrator mit.";
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
@@ -64,11 +68,11 @@ EOF
 
 # -----
 
-$Lang{H_BackupPC_Server_Status} = "BackupPC Server Status";
+$Lang{H_BackupPC_Server_Status} = "BackupPC Serverstatus";
 
 $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
 
-\${h2(\"Allgemeine Server Informationen\")}
+\${h2(\"Allgemeine Serverinformationen\")}
 
 <ul>
 <li>Die Server Prozess ID (PID) ist \$Info{pid}, auf Computer \$Conf{ServerHost},
@@ -85,7 +89,7 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
         <li>Das Pool Filesystem (Backup-Speicherplatz) ist zu \$Info{DUlastValue}%
             (\$DUlastTime) voll, das Maximum heute ist \$Info{DUDailyMax}% (\$DUmaxTime)
             und das Maximum gestern war \$Info{DUDailyMaxPrev}%. (Hinweis: Sollten ca. 70% berschritten werden, so
-	    ist evtl. bald eine Erweiterung des Backupspeichers erforderlich. Weitere Planung ntig?)
+	    ist evtl. bald eine Erweiterung des Backupspeichers erforderlich. Ist weitere Planung ntig?)
     </ul>
 </ul>
 EOF
@@ -97,7 +101,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 <p>
 \$generalInfo
 
-\${h2("Aktuell laufende Auftrge")}
+\${h2("Zur Zeit aktive Auftrge")}
 <p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td> Computer </td>
@@ -127,7 +131,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 EOF
 
 # --------------------------------
-$Lang{BackupPC__Server_Summary} = "BackupPC: Computer bersicht";
+$Lang{BackupPC__Server_Summary} = "BackupPC: Computerbersicht";
 $Lang{BackupPC__Archive} = "BackupPC: Archivierung";
 $Lang{BackupPC_Summary}=<<EOF;
 
@@ -150,11 +154,12 @@ Es gibt \$hostCntGood Computer die erfolgreich gesichert wurden, mit insgesamt:
 <tr class="tableheader"><td> Computer </td>
     <td align="center"> Benutzer </td>
     <td align="center"> #Voll </td>
-    <td align="center"> Alter/Tagen </td>
-    <td align="center"> Gre/GB </td>
+    <td align="center"> Alter (Tage) </td>
+    <td align="center"> Gre (GB) </td>
     <td align="center"> MB/sek </td>
     <td align="center"> #Inkr </td>
-    <td align="center"> Alter/Tage </td>
+    <td align="center"> Alter (Tage) </td>
+    <td align="center"> Letzes Backup (Tage) </td>
     <td align="center"> Status </td>
     <td align="center"> Letzte Aktion </td></tr>
 \$strGood
@@ -168,11 +173,12 @@ Es gibt \$hostCntNone Computer ohne Backups !!!
 <tr class="tableheader"><td> Computer </td>
     <td align="center"> Benutzer </td>
     <td align="center"> #Voll </td>
-    <td align="center"> Alter/Tage </td>
-    <td align="center"> Gre/GB </td>
-    <td align="center"> MB/sec </td>
+    <td align="center"> Alter (Tage) </td>
+    <td align="center"> Gre (GB) </td>
+    <td align="center"> MB/sek </td>
     <td align="center"> #Inkr </td>
-    <td align="center"> Alter/Tage </td>
+    <td align="center"> Alter (Tage) </td>
+    <td align="center"> Letztes Backup (Tage) </td>
     <td align="center"> Status </td>
     <td align="center"> Letzter Versuch </td></tr>
 \$strNone
@@ -216,7 +222,7 @@ Es gibt \$hostCntGood Computer die gesichert wurden, mit insgesamt \${fullSizeTo
 <input type="hidden" name="action" value="Archive">
 <table class="tableStnd" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td align=center>Computer</td>
-    <td align="center"> User </td>
+    <td align="center"> Benutzer </td>
     <td align="center"> Backup Gre </td>
 \$strGood
 \$checkAllHosts
@@ -241,7 +247,7 @@ Archivierung der folgenden Computer
 <table class="tableStnd" border cellspacing="1" cellpadding="3">
 \$paramStr
 <tr>
-    <td colspan=2><input type="submit" value="Archivierung starten" name=""></td>
+    <td colspan=2><input type="submit" value="Archivierung starten" name="ignore"></td>
 </tr>
 </form>
 </table>
@@ -249,7 +255,7 @@ EOF
 
 $Lang{BackupPC_Archive2_location} = <<EOF;
 <tr>
-    <td>Archivierung Ort/Gert</td>
+    <td>Archivierungsort/Gert</td>
     <td><input type="text" value="\$ArchiveDest" name="archive_device"></td>
 </tr>
 EOF
@@ -289,7 +295,7 @@ $Lang{Pool_Stat} = <<EOF;
 EOF
 
 # --------------------------------
-$Lang{BackupPC__Backup_Requested_on__host} = "BackupPC: Backup Auftrag fr \$host";
+$Lang{BackupPC__Backup_Requested_on__host} = "BackupPC: Backupauftrag fr \$host";
 # --------------------------------
 $Lang{REPLY_FROM_SERVER} = <<EOF;
 \${h1(\$str)}
@@ -299,24 +305,27 @@ Die Antwort des Servers war: \$reply
 Gehe zurck zur <a href="\$MyURL?host=\$host">\$host Hauptseite</a>.
 EOF
 # --------------------------------
-$Lang{BackupPC__Start_Backup_Confirm_on__host} = "BackupPC: Starte Backup Besttigung fr \$host";
+$Lang{BackupPC__Start_Backup_Confirm_on__host} = "BackupPC: Starte Backup von \$host";
 # --------------------------------
 $Lang{Are_you_sure_start} = <<EOF;
 \${h1("Sind Sie sicher?")}
 <p>
 Sie starten ein \$type Backup fr \$host.
 
-<form action="\$MyURL" method="get">
+<form name="Confirm" action="\$MyURL" method="get">
 <input type="hidden" name="host" value="\$host">
 <input type="hidden" name="hostIP" value="\$ipAddr">
 <input type="hidden" name="doit" value="1">
+<input type="hidden" name="action" value="">
 Mchten Sie das wirklich tun?
-<input type="submit" value="\$In{action}" name="action">
-<input type="submit" value="Nein" name="">
+<input type="button" value="\$buttonText"
+  onClick="document.Confirm.action.value='\$In{action}';
+           document.Confirm.submit();">
+<input type="submit" value="Nein" name="ignore">
 </form>
 EOF
 # --------------------------------
-$Lang{BackupPC__Stop_Backup_Confirm_on__host} = "BackupPC: Beende Backup Besttigung fr \$host";
+$Lang{BackupPC__Stop_Backup_Confirm_on__host} = "BackupPC: Beende Backup von \$host";
 # --------------------------------
 $Lang{Are_you_sure_stop} = <<EOF;
 
@@ -325,15 +334,18 @@ $Lang{Are_you_sure_stop} = <<EOF;
 <p>
 Sie werden Backups abbrechen bzw. Auftrge lschen fr Computer \$host;
 
-<form action="\$MyURL" method="get">
-<input type="hidden" name="host" value="\$host">
-<input type="hidden" name="doit" value="1">
+<form name="Confirm" action="\$MyURL" method="get">
+<input type="hidden" name="host"   value="\$host">
+<input type="hidden" name="doit"   value="1">
+<input type="hidden" name="action" value="">
 Zustzlich bitte keine Backups starten fr die Dauer von 
 <input type="text" name="backoff" size="10" value="\$backoff"> Stunden.
 <p>
 Mchten Sie das wirklich tun?
-<input type="submit" value="\$In{action}" name="action">
-<input type="submit" value="Nein" name="">
+<input type="button" value="\$buttonText"
+  onClick="document.Confirm.action.value='\$In{action}';
+           document.Confirm.submit();">
+<input type="submit" value="Nein" name="ignore">
 </form>
 
 EOF
@@ -342,14 +354,14 @@ $Lang{Only_privileged_users_can_view_queues_} = "Nur berechtigte Benutzer knnen
 # --------------------------------
 $Lang{Only_privileged_users_can_archive} = "Nur berechtigte Benutzer knnnen archivieren.";
 # --------------------------------
-$Lang{BackupPC__Queue_Summary} = "BackupPC: Warteschlangen bersicht";
+$Lang{BackupPC__Queue_Summary} = "BackupPC: Warteschlange bersicht";
 # --------------------------------
 $Lang{Backup_Queue_Summary} = <<EOF;
-\${h1("Backup Warteschlangen bersicht")}
+\${h1("Backup Warteschlangenbersicht")}
 <br><br>
-\${h2("bersicht Benutzer Auftrge in der Warteschlange")}
+\${h2("bersicht Benutzerauftrge in der Warteschlange")}
 <p>
-Die folgenden Benutzer Auftrge sind eingereiht:
+Die folgenden Benutzerauftrge sind eingereiht:
 </p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Computer </td>
@@ -359,9 +371,9 @@ Die folgenden Benutzer Auftrge sind eingereiht:
 </table>
 <br><br>
 
-\${h2("bersicht Hintergrund Auftrge in der Warteschlange")}
+\${h2("bersicht Hintergrundauftrge in der Warteschlange")}
 <p>
-Die folgenden Hintergrund Auftrge sind eingereiht:
+Die folgenden Hintergrundauftrge sind eingereiht:
 </p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Computer </td>
@@ -370,9 +382,9 @@ Die folgenden Hintergrund Auftrge sind eingereiht:
 \$strBg
 </table>
 <br><br>
-\${h2("bersicht Kommando Auftrge in der Warteschlange")}
+\${h2("bersicht Kommandoauftrge in der Warteschlange")}
 <p>
-Die folgenden Kommando Auftrge sind eingereiht:
+Die folgenden Kommandoauftrge sind eingereiht:
 </p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Computer </td>
@@ -427,14 +439,14 @@ EOF
  
 
 # ------------------------------
-$Lang{Browse_backup__num_for__host} = "BackupPC: Browsen des Backups \$num fr Computer \$host";
+$Lang{Browse_backup__num_for__host} = "BackupPC: Durchsuchen des Backups \$num fr Computer \$host";
 
 # ------------------------------
-$Lang{Restore_Options_for__host} = "BackupPC: Restore Optionen fr \$host";
+$Lang{Restore_Options_for__host} = "BackupPC: Wiederherstellungsoptionen fr \$host";
 $Lang{Restore_Options_for__host2} = <<EOF;
 \${h1("Restore Optionen fr \$host")}
 <p>
-Sie haben die folgenden Dateien/Verzeichnisse von der Freigabe \$share aus dem Backup mit der Nnummer #\$num selektiert:
+Sie haben die folgenden Dateien/Verzeichnisse aus der Freigabe \$share des Backups mit der Nummer #\$num selektiert:
 <ul>
 \$fileListStr
 </ul>
@@ -447,11 +459,11 @@ Bitte whlen Sie eine der folgenden Mglichkeiten:.
 EOF
 
 $Lang{Restore_Options_for__host_Option1} = <<EOF;
-Sie knnen diese Wiederherstellung starten um die Dateien/Verzeichnisse direkt auf den Computer  
-\$host wiederherzustellen. Alternativ knnen Sie einen anderen Computer und/oder Freigabe als Ziel angeben.
+Sie knnen diese Wiederherstellung starten um die Dateien/Verzeichnisse direkt auf den Computer \$host wiederherzustellen. 
+Alternativ knnen Sie einen anderen Computer und/oder Freigabe als Ziel angeben.
 </p><p>
-<b>Warnung:</b> alle aktuell existierenden Dateien/Verzeichnisse die bereits vorhanden sind
-werden berschrieben! (Tip: alternativ eine spezielle Freigabe erstellen mit Schreibrecht fr den
+<b>Warnung:</b> alle aktuell existierenden Dateien/Verzeichnisse, die bereits vorhanden sind,
+werden berschrieben! (Tip: Alternativ eine spezielle Freigabe erstellen mit Schreibrecht fr den
 Backup-Benutzer und die wiederhergestellten Dateien/Verzeichnisse durch Stichproben prfen, ob die beabsichtigte
 Wiederherstellung korrekt ist.) 
 </p>
@@ -461,7 +473,7 @@ Wiederherstellung korrekt ist.)
 <input type="hidden" name="type" value="3">
 \$hiddenStr
 <input type="hidden" value="\$In{action}" name="action">
-<table border="0">
+<table class="tableStnd" border="0">
 <tr>
     <td>Restore auf Computer</td>
     <td><!--<input type="text" size="40" value="\${EscHTML(\$host)}"
@@ -484,7 +496,7 @@ Wiederherstellung korrekt ist.)
     <td valign="top"><input type="text" size="40" maxlength="256"
 	value="\${EscHTML(\$pathHdr)}" name="pathHdr"></td>
 </tr><tr>
-    <td><input type="submit" value="Wiederherstellung starten" name=""></td>
+    <td><input type="submit" value="Wiederherstellung starten" name="ignore"></td>
 </table>
 </form>
 EOF
@@ -506,7 +518,7 @@ beliebige Dateien entpacken.
 <b>Warnung:</b> Abhngig von der Anzahl und Gre der selektierten
 Dateien/Verzeichnisse kann die ZIP Archiv Datei extrem gro bzw. zu gro werden. Der Download kann
 sehr lange dauern und der Speicherplatz auf Ihrem PC mu ausreichen. Selektieren Sie
-evtl. die Dateien/Verzeichnisse erneut und lassen sehr groe und unntige Dateien weg.  
+evtl. die Dateien/Verzeichnisse erneut und lassen sehr groe und unntige Dateien weg.
 </p>
 <form action="\$MyURL" method="post">
 <input type="hidden" name="host" value="\${EscHTML(\$host)}">
@@ -521,7 +533,7 @@ evtl. die Dateien/Verzeichnisse erneut und lassen sehr groe und unntige Dateien
 Kompression (0=aus, 1=schnelle,...,9=hchste)
 <input type="text" size="6" value="5" name="compressLevel">
 <br>
-<input type="submit" value="Zip Datei downloaden" name="">
+<input type="submit" value="Zip Datei downloaden" name="ignore">
 </form>
 EOF
 
@@ -547,9 +559,9 @@ enthlt. Mit einer lokalen Anwendung (z.B. tar, WinZIP...) knnen Sie dann
 beliebige Dateien entpacken.
 </p><p>
 <b>Warnung:</b> Abhngig von der Anzahl und Gre der selektierten
-Dateien/Verzeichnisse kann die Tar Archiv Datei extrem gro bzw. zu gro werden. Der Download kann
+Dateien/Verzeichnisse kann die Tar-Archiv Datei extrem gro bzw. zu gro werden. Der Download kann
 sehr lange dauern und der Speicherplatz auf Ihrem PC mu ausreichen. Selektieren Sie
-evtl. die Dateien/Verzeichnisse erneut und lassen sehr groe und unntige Dateien weg.  
+evtl. die Dateien/Verzeichnisse erneut und lassen sehr groe und unntige Dateien weg.
 </p>
 <form action="\$MyURL" method="post">
 <input type="hidden" name="host" value="\${EscHTML(\$host)}">
@@ -561,13 +573,13 @@ evtl. die Dateien/Verzeichnisse erneut und lassen sehr groe und unntige Dateien
  \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (andernfalls enthlt die Archiv Datei vollstndige Pfade).
 <br>
-<input type="submit" value="Tar Datei downloaden" name="">
+<input type="submit" value="Tar Datei downloaden" name="ignore">
 </form>
 EOF
 
 
 # ------------------------------
-$Lang{Restore_Confirm_on__host} = "BackupPC: Restore Confirm on \$host";
+$Lang{Restore_Confirm_on__host} = "BackupPC: Besttigung fr die Wiederherstellung auf \$host";
 
 $Lang{Are_you_sure} = <<EOF;
 \${h1("Sind Sie sicher?")}
@@ -576,22 +588,25 @@ Sie starten eine direkte Wiederherstellung auf den Computer \$In{hostDest}.
 Die folgenden Dateien werden auf die Freigabe \$In{shareDest} wiederhergestellt, von
 dem Backup mit der Nummer \$num:
 <p>
-<table border>
-<tr><td>Original Datei/Verzeichnis:</td><td>Wird wiederhergestellt nach:</td></tr>
+<table class="tableStnd" border>
+<tr class="tableheader"><td>Original Datei/Verzeichnis:</td><td>Wird wiederhergestellt nach:</td></tr>
 \$fileListStr
 </table>
 
-<form action="\$MyURL" method="post">
+<form name="RestoreForm" action="\$MyURL" method="post">
 <input type="hidden" name="host" value="\${EscHTML(\$host)}">
 <input type="hidden" name="hostDest" value="\${EscHTML(\$In{hostDest})}">
 <input type="hidden" name="shareDest" value="\${EscHTML(\$In{shareDest})}">
 <input type="hidden" name="pathHdr" value="\${EscHTML(\$In{pathHdr})}">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="type" value="4">
+<input type="hidden" name="action" value="">
 \$hiddenStr
 Wollen Sie das wirklich tun?
-<input type="submit" value="\$In{action}" name="action">
-<input type="submit" value="Nein" name="">
+<input type="button" value="\$Lang->{Restore}"
+ onClick="document.RestoreForm.action.value='Restore';
+          document.RestoreForm.submit();">
+<input type="submit" value="No" name="ignore">
 </form>
 EOF
 
@@ -601,7 +616,7 @@ $Lang{Restore_Requested_on__hostDest} = "BackupPC: Wiederherstellung beauftragt
 $Lang{Reply_from_server_was___reply} = <<EOF;
 \${h1(\$str)}
 <p>
-Die Antwort des BackupServers war: \$reply
+Die Antwort des Servers war: \$reply
 <p>
 Zurck zur <a href="\$MyURL?host=\$hostDest">\$hostDest Hauptseite</a>.
 EOF
@@ -609,41 +624,47 @@ EOF
 $Lang{BackupPC_Archive_Reply_from_server} = <<EOF;
 \${h1(\$str)}
 <p>
-Die Antwort vom Server war: \$reply
+Die Antwort des Server war: \$reply
 EOF
 
 # -------------------------
-$Lang{Host__host_Backup_Summary} = "BackupServer: Computer \$host Backup bersicht";
+$Lang{Host__host_Backup_Summary} = "BackupServer: Computer \$host Backupbersicht";
 
 $Lang{Host__host_Backup_Summary2} = <<EOF;
-\${h1("Computer \$host Backup bersicht")}
+\${h1("Computer \$host Backupbersicht")}
 <p>
 \$warnStr
 <ul>
 \$statusStr
 </ul>
 </p>
-\${h2("Benutzer Aktionen")}
+\${h2("Benutzeraktionen")}
 <p>
-<form action="\$MyURL" method="get">
-<input type="hidden" name="host" value="\$host">
+<form name="StartStopForm" action="\$MyURL" method="get">
+<input type="hidden" name="host"   value="\$host">
+<input type="hidden" name="action" value="">
 \$startIncrStr
-<input type="submit" value="$Lang{Start_Full_Backup}" name="action">
-<input type="submit" value="$Lang{Stop_Dequeue_Backup}" name="action">
+<input type="button" value="\$Lang->{Start_Full_Backup}"
+ onClick="document.StartStopForm.action.value='Start_Full_Backup';
+          document.StartStopForm.submit();">
+<input type="button" value="\$Lang->{Stop_Dequeue_Backup}"
+ onClick="document.StartStopForm.action.value='Stop_Dequeue_Backup';
+          document.StartStopForm.submit();">
 </form>
 </p>
-\${h2("Backup bersicht")}
+\${h2("Backupbersicht")}
 <p>
-Klicken Sie auf die Backupnummer um durch Dateien zu browsen und bei Bedarf wiederherzustellen.
+Klicken Sie auf die Backupnummer um die Dateien zu durchsuchen und bei Bedarf wiederherzustellen.
 </p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
-    <td align="center"> Filled </td>
+    <td align="center"> gefllt </td>
+    <td align="center"> Level </td>
     <td align="center"> Start Zeitpunkt </td>
     <td align="center"> Dauer/min </td>
     <td align="center"> Alter/Tage </td>
-    <td align="center"> Server Backup Pfad </td>
+    <td align="center"> Serverbackuppfad </td>
 </tr>
 \$str
 </table>
@@ -667,7 +688,7 @@ Klicken Sie auf die Backupnummer um durch Dateien zu browsen und bei Bedarf wied
 </table>
 <br><br>
 
-\${h2("Datei Gre/Anzahl Wiederverwendungs bersicht")}
+\${h2("Datei Gre/Anzahl Wiederverwendungsbersicht")}
 <p>
 "Bestehende Dateien" bedeutet bereits im Pool vorhanden.
 "Neue Dateien" bedeutet neu zum Pool hinzugefgt.
@@ -707,33 +728,38 @@ Kompressionsergebnisse fr bereits im Backup-Pool vorhandene und fr neu komprimie
     <td align="center"> Typ </td>
     <td align="center"> Komp Level </td>
     <td align="center"> Gre/MB </td>
-    <td align="center"> Comp/MB </td>
-    <td align="center"> Comp </td>
+    <td align="center"> Komp/MB </td>
+    <td align="center"> Komp </td>
     <td align="center"> Gre/MB </td>
-    <td align="center"> Comp/MB </td>
-    <td align="center"> Comp </td>
+    <td align="center"> Komp/MB </td>
+    <td align="center"> Komp </td>
 </tr>
 \$compStr
 </table>
 <br><br>
 EOF
 
-$Lang{Host__host_Archive_Summary} = "BackupPC: Host \$host Archive Summary";
+$Lang{Host__host_Archive_Summary} = "BackupPC: Host \$host Archivbersicht";
 $Lang{Host__host_Archive_Summary2} = <<EOF;
-\${h1("Host \$host Archiv bersicht")}
+\${h1("Host \$host Archivbersicht")}
 <p>
 \$warnStr
 <ul>
 \$statusStr
 </ul>
 
-\${h2("Benutzer Aktionen")}
+\${h2("Benutzeraktionen")}
 <p>
-<form action="\$MyURL" method="get">
+<form name="StartStopForm" action="\$MyURL" method="get">
 <input type="hidden" name="archivehost" value="\$host">
 <input type="hidden" name="host" value="\$host">
-<input type="submit" value="$Lang{Start_Archive}" name="action">
-<input type="submit" value="$Lang{Stop_Dequeue_Archive}" name="action">
+<input type="hidden" name="action" value="">
+<input type="button" value="\$Lang->{Start_Archive}"
+ onClick="document.StartStopForm.action.value='Start_Archive';
+          document.StartStopForm.submit();">
+<input type="button" value="\$Lang->{Stop_Dequeue_Archive}"
+ onClick="document.StartStopForm.action.value='Stop_Dequeue_Archive';
+          document.StartStopForm.submit();">
 </form>
 
 \$ArchiveStr
@@ -803,17 +829,17 @@ $Lang{Backup_browse_for__host} = <<EOF;
 <input type="hidden" name="host" value="\$host">
 <input type="hidden" name="share" value="\${EscHTML(\$share)}">
 <input type="hidden" name="fcbMax" value="\$checkBoxCnt">
-<input type="hidden" name="action" value="$Lang{Restore}">
+<input type="hidden" name="action" value="Restore">
 <br>
 <table width="100%">
-<tr><td valign="top">
-    <br><table align="center" border="0" cellpadding="0" cellspacing="0" bgcolor="#ffffff">
+<tr><td valign="top" width="30%">
+    <table align="left" border="0" cellpadding="0" cellspacing="0" bgcolor="#ffffff">
     \$dirStr
     </table>
 </td><td width="3%">
 </td><td valign="top">
     <br>
-        <table border="0" width="100%" align="left" cellpadding="3" cellspacing="1">
+        <table border width="100%" align="left" cellpadding="3" cellspacing="1">
         \$fileHeader
         \$topCheckAll
         \$fileStr
@@ -829,7 +855,7 @@ This is now in the checkAll row
 EOF
 
 # ------------------------------
-$Lang{DirHistory_backup_for__host} = "BackupPC: Verzeichnis Historie fr \$host";
+$Lang{DirHistory_backup_for__host} = "BackupPC: Verzeichnishistorie fr \$host";
 
 #
 # These two strings are used to build the links for directories and
@@ -839,7 +865,7 @@ $Lang{DirHistory_dirLink}  = "Verzeichnis";
 $Lang{DirHistory_fileLink} = "V";
 
 $Lang{DirHistory_for__host} = <<EOF;
-\${h1("Verzeichnis Sicherungs-Historie fr \$host")}
+\${h1("Verzeichnis Sicherungshistorie fr \$host")}
 <p>
 Diese Ansicht zeigt alle unterschiedlichen Versionen der Dateien in den Datensicherungen:
 <ul>
@@ -855,7 +881,7 @@ Diese Ansicht zeigt alle unterschiedlichen Versionen der Dateien in den Datensic
 \${h2("Historie von \${EscHTML(\$dirDisplay)}")}
 
 <br>
-<table cellspacing="2" cellpadding="3">
+<table border cellspacing="2" cellpadding="3">
 <tr class="fviewheader"><td>Datensicherungnummer</td>\$backupNumStr</tr>
 <tr class="fviewheader"><td>Sicherungszeitpunkt</td>\$backupTimeStr</tr>
 \$fileStr
@@ -920,7 +946,7 @@ $Lang{Archive___num_details_for__host2 } = <<EOF;
 </tr></tr>
 </table>
 <p>
-\${h1("Computer Liste")}
+\${h1("Computerliste")}
 <p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td>Computer</td><td>Datensicherungsnummer</td></tr>
@@ -929,12 +955,12 @@ $Lang{Archive___num_details_for__host2 } = <<EOF;
 EOF
 
 # -----------------------------------
-$Lang{Email_Summary} = "BackupPC: eMail bersicht";
+$Lang{Email_Summary} = "BackupPC: Emailbersicht";
 
 # -----------------------------------
 #  !! ERROR messages !!
 # -----------------------------------
-$Lang{BackupPC__Lib__new_failed__check_apache_error_log} = "BackupPC::Lib->new failed: berprfen Sie die Apache error_log\n";
+$Lang{BackupPC__Lib__new_failed__check_apache_error_log} = "BackupPC::Lib->new failed: berprfen Sie das Apache error_log\n";
 $Lang{Wrong_user__my_userid_is___} =  
               "Falscher Benutzer: Meine userid ist \$>, anstelle \$uid"
             . "(\$Conf{BackupPCUser})\n";
@@ -947,7 +973,7 @@ $Lang{Unable_to_open__file__configuration_problem} = "kann Datei nicht ffnen \$f
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Nur berechtigte Benutzer knnen Log oder Config Dateien einsehen.";
 $Lang{Only_privileged_users_can_view_log_files} = "Nur berechtigte Benutzer knnen LOG Dateien einsehen.";
 $Lang{Only_privileged_users_can_view_email_summaries} = "Nur berechtigte Benutzer knnen die Email bersicht einsehen.";
-$Lang{Only_privileged_users_can_browse_backup_files} = "Nur berechtigte Benutzer knnen Backup Dateien browsen"
+$Lang{Only_privileged_users_can_browse_backup_files} = "Nur berechtigte Benutzer knnen Backup Dateien durchsuchen"
                 . " fr computer \${EscHTML(\$In{host})}.";
 $Lang{Empty_host_name} = "Kein Hostname.";
 $Lang{Directory___EscHTML} = "Verzeichnis \${EscHTML(\"\$TopDir/pc/\$host/\$num\")}"
@@ -964,8 +990,8 @@ $Lang{Nice_try__but_you_can_t_put} = "Sie drfen \'..\' nicht in Dateinamen verwe
 $Lang{Host__doesn_t_exist} = "Computer \${EscHTML(\$In{hostDest})} existiert nicht";
 $Lang{You_don_t_have_permission_to_restore_onto_host} = "Sie haben keine Berechtigung zum Restore auf Computer"
 		    . " \${EscHTML(\$In{hostDest})}";
-$Lang{Can_t_open_create} = "Kann Datei nicht ffnen oder erstellen "
-                    . "\${EscHTML(\"\$TopDir/pc/\$hostDest/\$reqFileName\")}";
+$Lang{Can_t_open_create__openPath} = "Kann Datei nicht ffnen oder erstellen "
+		. "\${EscHTML(\"\$openPath\")}";
 $Lang{Only_privileged_users_can_restore_backup_files2} = "Nur berechtigte Benutzer drfen Backup und Restore von Dateien"
                 . " fr Computer \${EscHTML(\$host)} durchfhren.";
 $Lang{Empty_host_name} = "leerer Computer Name";
@@ -1004,13 +1030,13 @@ $Lang{Archive_requested} = "Archivierung beauftragt durch \$User von \$ENV{REMOT
 # -------------------------------------------------
 
 $Lang{Status} = "Status";
-$Lang{PC_Summary} = "Computer bersicht";
+$Lang{PC_Summary} = "Computerbersicht";
 $Lang{LOG_file} = "LOG Datei";
 $Lang{LOG_files} = "LOG Dateien";
 $Lang{Old_LOGs} = "Alte LOG Dateien";
-$Lang{Email_summary} = "eMail bersicht";
-$Lang{Config_file} = "Config Datei";
-$Lang{Hosts_file} = "Hosts Datei";
+$Lang{Email_summary} = "Emailbersicht";
+$Lang{Config_file} = "Konfigurationsdatei";
+# $Lang{Hosts_file} = "Hosts Datei";
 $Lang{Current_queues} = "Warteschlangen";
 $Lang{Documentation} = "Dokumentation";
 
@@ -1038,17 +1064,17 @@ EOF
 
 # -----------
 $Lang{Host_host_is_queued_on_the_background_queue_will_be_backed_up_soon} = <<EOF;
-<li>Computer \$host ist in die Hintergrund-Warteschlange eingereiht (Backup wird bald gestartet).
+<li>Computer \$host ist in die Hintergrundwarteschlange eingereiht (Backup wird bald gestartet).
 EOF
 
 # ----------
 $Lang{Host_host_is_queued_on_the_user_queue__will_be_backed_up_soon} = <<EOF;
-<li>Computer \$host ist in die Benutzer-Warteschlange eingereiht (Backup wird bald gestartet).
+<li>Computer \$host ist in die Benutzerwarteschlange eingereiht (Backup wird bald gestartet).
 EOF
 
 # ---------
 $Lang{A_command_for_host_is_on_the_command_queue_will_run_soon} = <<EOF;
-<li>Ein Kommando fr Computer \$host ist in der Kommando-Warteschlange (wird bald ausgefhrt).
+<li>Ein Kommando fr Computer \$host ist in der Kommandowarteschlange (wird bald ausgefhrt).
 EOF
 
 # --------
@@ -1085,7 +1111,7 @@ $Lang{__time0_to__time1_on__days} = "\$t0 bis \$t1 am \$days";
 
 $Lang{Backups_are_deferred_for_hours_hours_change_this_number} = <<EOF;
 <li>Backups sind fr die nchsten \$hours Stunden deaktiviert.
-(<a href=\"\$MyURL?action=\${EscURI(\$Lang->{Stop_Dequeue_Archive})}&host=\$host\">diese Zeit ndern</a>).
+(<a href=\"\$MyURL?action=Stop_Dequeue_Backup&host=\$host\">diese Zeit ndern</a>).
 EOF
 
 $Lang{tryIP} = " und \$StatusHost{dhcpHostIP}";
@@ -1175,7 +1201,7 @@ $Lang{The_directory_is_empty} = <<EOF;
 </td></tr>
 EOF
 
-#$Lang{on} = "on";
+#$Lang{on} = "an";
 $Lang{off} = "aus";
 
 $Lang{backupType_full}    = "voll";
@@ -1207,6 +1233,8 @@ $Lang{Reason_no_ping} = "nicht erreichbar";
 $Lang{Reason_backup_canceled_by_user} = "Abbruch durch Benutzer";
 $Lang{Reason_restore_canceled_by_user} = "Abbruch durch Benutzer";
 $Lang{Reason_archive_canceled_by_user} = "Archivierung abgebrochen durch Benutzer";
+$Lang{Disabled_OnlyManualBackups}  = "autom. deaktiviert";
+$Lang{Disabled_AllBackupsDisabled} = "deaktiviert";
 
 # ---------
 # Email messages
@@ -1217,7 +1245,7 @@ $Lang{EMailNoBackupEverMesg} = <<'EOF';
 To: $user$domain
 cc:
 Subject: $subj
-
+$headers
 Hallo $userName,
 
 Ihr Computer ($host) wurde durch den Backup Server noch nie erfolgreich gesichert.
@@ -1236,9 +1264,8 @@ Andernfalls sollten Sie sicherstellen, da Ihr Computer regelmig korrekt am Netzw
 angeschlossen wird.
 
 Mit freundlichen Gren,
-Ihr BackupServer
+Ihr BackupPC Server
 http://backuppc.sourceforge.net
-http://www.zipptec.de
 EOF
 
 # No recent backup
@@ -1247,7 +1274,7 @@ $Lang{EMailNoBackupRecentMesg} = <<'EOF';
 To: $user$domain
 cc:
 Subject: $subj
-
+$headers
 Hallo $userName,
 
 Ihr Computer ($host) wurde seit $days Tagen nicht mehr erfolgreich gesichert.
@@ -1259,31 +1286,30 @@ Backups sollten automatisch erfolgen, wenn Ihr Computer am Netzwerk angeschlosse
 Wenn Ihr Computer in den letzten $days Tagen mehr als ein paar Stunden am
 Netzwerk angeschlossen war, sollten Sie Ihren Backup-Betreuer oder
 den IT-Dienstleister kontaktieren um die Ursache zu ermitteln und zu beheben.
-Andernfalls, wenn Sie z. B. lange Zeit nicht im Bro sind, knnen Sie hchstens
+Andernfalls, wenn Sie z.B. lange Zeit nicht im Bro sind, knnen Sie hchstens
 manuell Ihre Dateien sichern (evtl. kopieren auf eine externe Festplatte).
 
-Bitte denken Sie daran, dass alle in den letzten $days Tagen genderten Dateien (z. B.
-auch e-mails und Anhnge oder Datenbankeintrge) verloren gehen falls Ihre
-Festplatte einen crash erleidet oder Dateien durch versehentliches Lschen oder
+Bitte denken Sie daran, dass alle in den letzten $days Tagen genderten Dateien (z.B.
+auch Emails und Anhnge oder Datenbankeintrge) verloren gehen falls Ihre
+Festplatte ausfllt oder Dateien durch versehentliches Lschen oder
 Virenbefall unbrauchbar werden.
 
 Mit freundlichen Gren,
-Ihr BackupServer
+Ihr BackupPC Server
 http://backuppc.sourceforge.net
-http://www.zipptec.de
 EOF
 
 # Old Outlook files
-$Lang{EMailOutlookBackupSubj} = "BackupServer: Outlook Dateien auf Computer \$host - Sicherung erforderlich";
+$Lang{EMailOutlookBackupSubj} = "BackupServer: Outlook-Dateien auf Computer \$host - Sicherung erforderlich";
 $Lang{EMailOutlookBackupMesg} = <<'EOF';
 To: $user$domain
 cc:
 Subject: $subj
-
+$headers
 Hallo $userName,
 
 die Outlook Dateien auf Ihrem Computer wurden $howLong Tage nicht gesichert.
-Diese Dateien enthalten Ihre e-mails, Anhnge, Adressen und Kalender.
+Diese Dateien enthalten Ihre Emails, Anhnge, Adressen und Kalender.
 
 Ihr Computer wurde zwar $numBackups mal seit $firstTime Tagen bis vor $lastTime Tagen
 gesichert. Allerdings sperrt Outlook den Zugriff auf diese Dateien.
@@ -1292,24 +1318,156 @@ Es wird folgendes Vorgehen empfohlen:
 
 1. Der Computer muss an das BackupServer Netzwerk angeschlossen sein.
 2. Beenden Sie das Outlook Programm.
-3. Starten Sie ein incrementelles Backup mit dem Internet-Browser hier: 
+3. Starten Sie ein inkrementelles Backup mit dem Internet-Browser hier: 
 
     $CgiURL?host=$host               
 
     Name und Passwort eingeben und dann 2 mal nacheinander
-    auf "Starte Backup incrementell" klicken
-    Klicken Sie auf "Gehe zurck zur ...home page" und beobachten Sie
-    den Status des Backup-Vorgangs (Browser von Zeit zu Zeit aktualisieren).
+    auf "Starte inkrementelles Backup" klicken
+    Klicken Sie auf "Gehe zurck zur ...Hauptseite" und beobachten Sie
+    den Status des Backupvorgangs (Browser von Zeit zu Zeit aktualisieren).
     Das sollte je nach Dateigre nur eine kurze Zeit dauern.
     
 
 Mit freundlichen Gren,
-Ihr BackupServer
+Ihr BackupPC Server
 http://backuppc.sourceforge.net
-http://www.zipptec.de
 EOF
 
 $Lang{howLong_not_been_backed_up} = "Backup nicht erfolgreich";
-$Lang{howLong_not_been_backed_up_for_days_days} = "kein Backup seit \$days Tagen";
+$Lang{howLong_not_been_backed_up_for_days_days} = "Kein Backup seit \$days Tagen";
 
+#######################################################################
+# RSS strings
+#######################################################################
+$Lang{RSS_Doc_Title}       = "BackupPC Server";
+$Lang{RSS_Doc_Description} = "RSS Feed fr BackupPC";
+$Lang{RSS_Host_Summary}    = <<EOF;
+#Voll: \$fullCnt;
+Alter/Tagen: \$fullAge;
+Gre/GB: \$fullSize;
+MB/sek: \$fullRate;
+#Inkr: \$incrCnt;
+Alter/Tage: \$incrAge;
+Status: \$host_state;
+Letzte Aktion: \$host_last_attempt;
+EOF
+
+#######################################################################
+# Configuration editor strings
+#######################################################################
+
+$Lang{Only_privileged_users_can_edit_config_files} = "Nur privilegierte Nutzer knnen die Administrationsoptionen ndern.";
+$Lang{CfgEdit_Edit_Config} = "Konfiguration ndern";
+$Lang{CfgEdit_Edit_Hosts}  = "Hosts ndern";
+
+$Lang{CfgEdit_Title_Server} = "Server";
+$Lang{CfgEdit_Title_General_Parameters} = "Allgemeine Einstellungen";
+$Lang{CfgEdit_Title_Wakeup_Schedule} = "Aktivierungsplan";
+$Lang{CfgEdit_Title_Concurrent_Jobs} = "gleichzeitige Auftrge";
+$Lang{CfgEdit_Title_Pool_Filesystem_Limits} = "Pooldateisystem Begrenzungen";
+$Lang{CfgEdit_Title_Other_Parameters} = "Andere Einstellungen";
+$Lang{CfgEdit_Title_Remote_Apache_Settings} = "Apache Remote Einstellungen";
+$Lang{CfgEdit_Title_Program_Paths} = "Programmpfade";
+$Lang{CfgEdit_Title_Install_Paths} = "Installationspfade";
+$Lang{CfgEdit_Title_Email} = "Email";
+$Lang{CfgEdit_Title_Email_settings} = "Email Einstellungen";
+$Lang{CfgEdit_Title_Email_User_Messages} = "Email Benutzernachrichten";
+$Lang{CfgEdit_Title_CGI} = "CGI";
+$Lang{CfgEdit_Title_Admin_Privileges} = "Admininistrationsprivilegien";
+$Lang{CfgEdit_Title_Page_Rendering} = "Seitenrendering";
+$Lang{CfgEdit_Title_Paths} = "Pfade";
+$Lang{CfgEdit_Title_User_URLs} = "Benutzer URLs";
+$Lang{CfgEdit_Title_User_Config_Editing} = "Benutzerkonfiguration ndern";
+$Lang{CfgEdit_Title_Xfer} = "Xfer";
+$Lang{CfgEdit_Title_Xfer_Settings} = "Xfer Einstellungen";
+$Lang{CfgEdit_Title_Smb_Settings} = "Smb Einstellungen";
+$Lang{CfgEdit_Title_Tar_Settings} = "Tar Einstellungen";
+$Lang{CfgEdit_Title_Rsync_Settings} = "Rsync Einstellungen";
+$Lang{CfgEdit_Title_Rsyncd_Settings} = "Rsyncd Einstellungen";
+$Lang{CfgEdit_Title_BackupPCd_Settings} = "BackupPCd Einstellungen";
+$Lang{CfgEdit_Title_Archive_Settings} = "Archive Einstellungen";
+$Lang{CfgEdit_Title_Include_Exclude} = "Include/Exclude";
+$Lang{CfgEdit_Title_Smb_Paths_Commands} = "Smb Pfade/Kommandos";
+$Lang{CfgEdit_Title_Tar_Paths_Commands} = "Tar Pfade/Kommandos";
+$Lang{CfgEdit_Title_Rsync_Paths_Commands_Args} = "Rsync Pfade/Kommandos/Argumente";
+$Lang{CfgEdit_Title_Rsyncd_Port_Args} = "Rsyncd Port/Argumente";
+$Lang{CfgEdit_Title_Archive_Paths_Commands} = "Archive Pfade/Kommandos";
+$Lang{CfgEdit_Title_Schedule} = "Backupplan";
+$Lang{CfgEdit_Title_Full_Backups} = "volle Backups";
+$Lang{CfgEdit_Title_Incremental_Backups} = "inkrementelle Backups";
+$Lang{CfgEdit_Title_Blackouts} = "Blackouts";
+$Lang{CfgEdit_Title_Other} = "Andere";
+$Lang{CfgEdit_Title_Backup_Settings} = "Backup Einstellungen";
+$Lang{CfgEdit_Title_Client_Lookup} = "Auflsen des Klienten";
+$Lang{CfgEdit_Title_Other} = "Andere Werte";
+$Lang{CfgEdit_Title_User_Commands} = "Benutzer Kommandos";
+$Lang{CfgEdit_Title_Hosts} = "Hosts";
+
+$Lang{CfgEdit_Hosts_Comment} = <<EOF;
+Um einen neuen Hosts hinzuzufgen, whle Hinzufgen und gib 
+dann den Namen ein. Um mit der Konfigurationvorlage eines anderen Hosts
+zu beginnen, gib als Namen NEWHOST=COPYHOST ein. Dies wird alle
+bereits bestehenden hostspezifischen Einstellungen fr NEWHOST
+mit den Werten von COPYHOST berschreiben. Du kannst dies auch fr einen bereits 
+bestehenden Hosts machen. Um einen Host zu lschen, whle den Lschen Knopf.
+Das Hinzufgen, Lschen und Kopieren von Konfigurationen pro Host
+wird erst durch whlen von Speichern aktiviert. Bereits bestehende
+Backups werden beim Lschen eines Hosts nicht mitgelscht. Nach einem
+erneuten Anlegen des selben Hosts sind alle alten Backups wieder verfgbar.
+Um Backups vollstndig zu entfernen mssen die Dateien unter \$topDir/pc/HOST
+gelscht werden.
+EOF
+
+$Lang{CfgEdit_Header_Main} = <<EOF;
+\${h1("Allgemeiner Konfigurationseditor")}
+EOF
+
+$Lang{CfgEdit_Header_Host} = <<EOF;
+\${h1("Host \$host Konfigurationseditor")}
+<p>
+Beachte: Whle berschreiben, wenn du einen computerspezifischen Wert verndern willst 
+<p>
+EOF
+
+$Lang{CfgEdit_Button_Save}     = "Speichern";
+$Lang{CfgEdit_Button_Insert}   = "Einfgen";
+$Lang{CfgEdit_Button_Delete}   = "Lschen";
+$Lang{CfgEdit_Button_Add}      = "Hinzufgen";
+$Lang{CfgEdit_Button_Override} = "berschreiben";
+$Lang{CfgEdit_Button_New_Key}  = "Neuer Schlssel";
+
+$Lang{CfgEdit_Error_No_Save}
+            = "Wegen Fehlern nicht gesichert";
+$Lang{CfgEdit_Error__must_be_an_integer}
+            = "Error: \$var muss eine Zahl sein";
+$Lang{CfgEdit_Error__must_be_real_valued_number}
+            = "Error: \$var muss eine ganze Zahl sein";
+$Lang{CfgEdit_Error__entry__must_be_an_integer}
+            = "Error: \$var Eintrag \$k muss eine Zahl sein";
+$Lang{CfgEdit_Error__entry__must_be_real_valued_number}
+            = "Error: \$var Eintrag \$k muss eine ganze Zahl sein";
+$Lang{CfgEdit_Error__must_be_executable_program}
+            = "Error: \$var muss ein gltiger ausfhrbarer Pfad sein";
+$Lang{CfgEdit_Error__must_be_valid_option}
+            = "Error: \$var muss eine gltige Option sein";
+$Lang{CfgEdit_Error_Copy_host_does_not_exist}
+            = "Ursprungs Host \$copyHost existiert nicht; Erstelle den vollen Hostnamen \$fullHost.  Lsche den Host wenn das nicht war, was du wolltest.";
+
+$Lang{CfgEdit_Log_Copy_host_config}
+            = "\$User hat die Konfig von host \$fromHost zu \$host kopiert\n";
+$Lang{CfgEdit_Log_Delete_param}
+            = "\$User hat \$p von \$conf gelscht\n";
+$Lang{CfgEdit_Log_Add_param_value}
+            = "\$User hat \$p zu \$conf hinzugefgt und den Wert \$value gegeben\n";
+$Lang{CfgEdit_Log_Change_param_value}
+            = "\$User nderte \$p in \$conf zu \$valueNew von \$valueOld\n";
+$Lang{CfgEdit_Log_Host_Delete}
+            = "\$User hat den Host \$host gelscht\n";
+$Lang{CfgEdit_Log_Host_Change}
+            = "\$User Host \$host hat den Schlssel \$key von \$valueOld zu \$valueNew gendert\n";
+$Lang{CfgEdit_Log_Host_Add}
+            = "\$User hat den Host \$host: \$value hinzugefgt\n";
+  
 #end of lang_de.pm
+
