@@ -1,10 +1,11 @@
 #!/bin/perl
 #
-# $Id: it.pm,v 1.9 2004/06/20 02:21:02 cbarratt Exp $
-#
 # Italian i18n file
 #
 # (C)  Lorenzo Cappelletti <lorenzo.cappelletti@email.it>  2004
+#  Added translations and corrections:
+#  Giuseppe Iuculano 2006
+#  Vittorio Macchi 2006
 #
 
 
@@ -29,16 +30,18 @@ $Lang{Admin_Options_Page} = <<EOF;
 \${h1(qq{$Lang{Admin_Options}})}
 <br>
 \${h2("Controllo server")}
-<form action="\$MyURL" method="get">
+<form name="ReloadForm" action="\$MyURL" method="get">
+<input type="hidden" name="action" value="">
 <table class="tableStnd">
-<!--<tr><td>Arresta il server:<td><input type="submit" name="action" value="Stop">-->
-  <tr><td>Ricarica la configurazione del server:<td><input type="submit" name="action" value="Reload">
+  <tr><td>Ricarica la configurazione del server:<td><input type="button" value="Reload"
+     onClick="document.ReloadForm.action.value='Reload';
+              document.ReloadForm.submit();">
 </table>
 </form>
 <!--
 \${h2("Configurazione server")}
 <ul>
-  <li><i>Other options can go here... e.g.,</i>
+  <li><i>Altre opzioni possono andare qui... e.g.,</i>
   <li>Modifica configurazione server
 </ul>
 -->
@@ -47,7 +50,7 @@ $Lang{Unable_to_connect_to_BackupPC_server} = "Impossibile connettersi al server
             "Questo script CGI (\$MyURL) non &egrave; in grado di connettersi al server"
           . " BackupPC su \$Conf{ServerHost} alla porta \$Conf{ServerPort}.  L'errore &egrave;:"
           . " \$err.",
-            "Forse il server BackupPC non &egrave; in esecuzioneor c'&egrave; un errore"
+            "Forse il server BackupPC non &egrave; in esecuzione o c'&egrave; un errore"
           . " nella configurazione.  Contattare l'amministratore di sistema.";
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
@@ -133,11 +136,11 @@ $Lang{BackupPC_Summary} = <<EOF;
 Questo rapporto di stato &egrave; stato generato il \$now.
 </p>
 
-\${h2("Host con backup buoni")}
+\${h2("Host con backup validi")}
 <p>
 Ci sono \$hostCntGood host sottoposti a backup per un totale di:
 <ul>
-<li> \$fullTot backup completi per una dimensione toatle di \${fullSizeTot}GB
+<li> \$fullTot backup completi per una dimensione totale di \${fullSizeTot}GB
      (prima del processo di pooling e compressione),
 <li> \$incrTot backup incrementali per una dimensione totale di \${incrSizeTot}GB
      (prima del processo di pooling e compressione).
@@ -149,9 +152,10 @@ Ci sono \$hostCntGood host sottoposti a backup per un totale di:
     <td align="center"> Completi </td>
     <td align="center"> Et&agrave; completi (giorni) </td>
     <td align="center"> Dimensione completi (GB) </td>
-    <td align="center"> Velocit&agrave (MB/s) </td>
+    <td align="center"> Velocit&agrave; (MB/s) </td>
     <td align="center"> Incrementali </td>
     <td align="center"> Et&agrave; incrementali (giorni) </td>
+    <td align="center"> Ultimo Backup (giorni) </td>
     <td align="center"> Stato </td>
     <td align="center"> Ultimo tentativo </td></tr>
 \$strGood
@@ -167,9 +171,10 @@ Ci sono \$hostCntNone host senza alcun backup.
     <td align="center"> Completi </td>
     <td align="center"> Et&agrave; completi (giorni) </td>
     <td align="center"> Dimensione completi (GB) </td>
-    <td align="center"> Velocit&agrave (MB/s) </td>
+    <td align="center"> Velocit&agrave; (MB/s) </td>
     <td align="center"> Incrementali </td>
     <td align="center"> Et&agrave; incrementali (giorni) </td>
+    <td align="center"> Ultimo Backup (giorni) </td>
     <td align="center"> Stato </td>
     <td align="center"> Ultimo tentativo </td></tr>
 \$strNone
@@ -240,7 +245,7 @@ Gli host seguenti stanno per esseri archiviati
 <table class="tableStnd" border cellspacing="1" cellpadding="3">
 \$paramStr
 <tr>
-    <td colspan=2><input type="submit" value="Avvia archiviazione" name=""></td>
+    <td colspan=2><input type="submit" value="Avvia archiviazione" name="ignore"></td>
 </tr>
 </form>
 </table>
@@ -294,7 +299,7 @@ $Lang{BackupPC__Backup_Requested_on__host} = "BackupPC: richiesta di backup per
 $Lang{REPLY_FROM_SERVER} = <<EOF;
 \${h1(\$str)}
 <p>
-La risposta del server &grave; stata: \$reply
+La risposta del server &egrave; stata: \$reply
 <p>
 Ritorna alla <a href="\$MyURL?host=\$host">homepage di \$host</a>.
 EOF
@@ -304,15 +309,18 @@ $Lang{BackupPC__Start_Backup_Confirm_on__host} = "BackupPC: conferma avvio backu
 $Lang{Are_you_sure_start} = <<EOF;
 \${h1("Sicuro?")}
 <p>
-Si sta per avviare un bakcup \$type per \$host.
+Si sta per avviare un backup \$type per \$host.
 
-<form action="\$MyURL" method="get">
+<form name="Confirm" action="\$MyURL" method="get">
 <input type="hidden" name="host" value="\$host">
 <input type="hidden" name="hostIP" value="\$ipAddr">
 <input type="hidden" name="doit" value="1">
+<input type="hidden" name="action" value="">
 Avviare veramente?
-<input type="submit" value="\$In{action}" name="action">
-<input type="submit" value="No" name="">
+<input type="button" value="\$buttonText"
+  onClick="document.Confirm.action.value='\$In{action}';
+           document.Confirm.submit();">
+<input type="submit" value="No" name="ignore">
 </form>
 EOF
 # --------------------------------
@@ -325,15 +333,18 @@ $Lang{Are_you_sure_stop} = <<EOF;
 <p>
 Si sta per arrestare/disaccodare i backup per \$host;
 
-<form action="\$MyURL" method="get">
-<input type="hidden" name="host" value="\$host">
-<input type="hidden" name="doit" value="1">
+<form name="Confirm" action="\$MyURL" method="get">
+<input type="hidden" name="host"   value="\$host">
+<input type="hidden" name="doit"   value="1">
+<input type="hidden" name="action" value="">
 Also, please don\'t start another backup for
 <input type="text" name="backoff" size="10" value="\$backoff"> hours.
 <p>
 Arrestare veramente?
-<input type="submit" value="\$In{action}" name="action">
-<input type="submit" value="No" name="">
+<input type="button" value="\$buttonText"
+  onClick="document.Confirm.action.value='\$In{action}';
+           document.Confirm.submit();">
+<input type="submit" value="No" name="ignore">
 </form>
 
 EOF
@@ -460,7 +471,7 @@ sar&agrave; sovrascritto!
 <input type="hidden" name="type" value="3">
 \$hiddenStr
 <input type="hidden" value="\$In{action}" name="action">
-<table border="0">
+<table class="tableStnd" border="0">
 <tr>
     <td>Ripristino dei file sull\'host</td>
     <td><!--<input type="text" size="40" value="\${EscHTML(\$host)}"
@@ -473,7 +484,7 @@ sar&agrave; sovrascritto!
                window.open(URL,'','width=500,height=400');
         }
         </script>
-        <!--<a href="javascript:myOpen('\$MyURL?action=findShares&host='+document.direct.hostDest.options.value)">Search for available shares (NOT IMPLEMENTED)</a>--></td>
+        <!--<a href="javascript:myOpen('\$MyURL?action=findShares&host='+document.direct.hostDest.options.value)">Cerca condivisioni disponibili (NON IMPLEMENTATO)</a>--></td>
 </tr><tr>
     <td>Ripristino dei file sulla condivisione</td>
     <td><input type="text" size="40" value="\${EscHTML(\$share)}"
@@ -484,14 +495,14 @@ sar&agrave; sovrascritto!
     <td valign="top"><input type="text" size="40" maxlength="256"
 	value="\${EscHTML(\$pathHdr)}" name="pathHdr"></td>
 </tr><tr>
-    <td><input type="submit" value="Avvio ripristino" name=""></td>
+    <td><input type="submit" value="Avvio ripristino" name="ignore"></td>
 </table>
 </form>
 EOF
 
 $Lang{Restore_Options_for__host_Option1_disabled} = <<EOF;
-Direct restore has been disabled for host \${EscHTML(\$hostDest)}.
-Please select one of the other restore options.
+Il ripristino diretto &egrave; stato disabilitato per l\'host host \${EscHTML(\$hostDest)}.
+Per favore, seleziona uno degli altri metodi di ripristino.
 EOF
   
 # ------------------------------
@@ -521,7 +532,7 @@ l\'archivio relativamente a \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 Compressione (0=off, 1=fast,...,9=best)
 <input type="text" size="6" value="5" name="compressLevel">
 <br>
-<input type="submit" value="Scarica file zip" name="">
+<input type="submit" value="Scarica file zip" name="ignore">
 </form>
 EOF
 
@@ -533,7 +544,7 @@ $Lang{Option_2__Download_Zip_archive2} = <<EOF;
 <p>
 Archive::Zip non &egrave; installato e non &egrave; quindi possibile
 scaricare un archivio zip.
-Contattare l\'amministratore di sistemaper installare Archive::Zip da
+Contattare l\'amministratore di sistema per installare Archive::Zip da
 <a href="http://www.cpan.org">www.cpan.org</a>.
 </p>
 EOF
@@ -562,7 +573,7 @@ abbastanza spazio sul proprio disco rigido locale per poterlo contenere.
 l\'archivio relativamente a \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (altrimenti l\'archivio conterr&agrave; percorsi completi).
 <br>
-<input type="submit" value="Scarica file tar" name="">
+<input type="submit" value="Scarica file tar" name="ignore">
 </form>
 EOF
 
@@ -577,22 +588,25 @@ Si sta per avviare il ripristino diretto sulla macchina \$In{hostDest}.
 I file seguenti saranno ripristinati sulla condivisione \$In{shareDest}
 dal backup numero \$num:
 <p>
-<table border>
-<tr><td>File/directory originale</td><td>Ripristinato su</td></tr>
+<table class="tableStnd" border>
+<tr class="tableheader"><td>File/directory originale</td><td>Ripristinato su</td></tr>
 \$fileListStr
 </table>
 
-<form action="\$MyURL" method="post">
+<form name="RestoreForm" action="\$MyURL" method="post">
 <input type="hidden" name="host" value="\${EscHTML(\$host)}">
 <input type="hidden" name="hostDest" value="\${EscHTML(\$In{hostDest})}">
 <input type="hidden" name="shareDest" value="\${EscHTML(\$In{shareDest})}">
 <input type="hidden" name="pathHdr" value="\${EscHTML(\$In{pathHdr})}">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="type" value="4">
+<input type="hidden" name="action" value="">
 \$hiddenStr
 Avviare veramente?
-<input type="submit" value="\$In{action}" name="action">
-<input type="submit" value="No" name="">
+<input type="button" value="\$Lang->{Restore}"
+ onClick="document.RestoreForm.action.value='Restore';
+          document.RestoreForm.submit();">
+<input type="submit" value="No" name="ignore">
 </form>
 EOF
 
@@ -602,7 +616,7 @@ $Lang{Restore_Requested_on__hostDest} = "BackupPC: ripristino richiesto per \$ho
 $Lang{Reply_from_server_was___reply} = <<EOF;
 \${h1(\$str)}
 <p>
-La risposta del server &grave; stata: \$reply
+La risposta del server &egrave; stata: \$reply
 <p>
 Ritorna alla <a href="\$MyURL?host=\$hostDest">homepage di \$hostDest</a>.
 EOF
@@ -627,20 +641,26 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 </p>
 \${h2("Azioni utente")}
 <p>
-<form action="\$MyURL" method="get">
-<input type="hidden" name="host" value="\$host">
+<form name="StartStopForm" action="\$MyURL" method="get">
+<input type="hidden" name="host"   value="\$host">
+<input type="hidden" name="action" value="">
 \$startIncrStr
-<input type="submit" value="$Lang{Start_Full_Backup}" name="action">
-<input type="submit" value="$Lang{Stop_Dequeue_Backup}" name="action">
+<input type="button" value="\$Lang->{Start_Full_Backup}"
+ onClick="document.StartStopForm.action.value='Start_Full_Backup';
+          document.StartStopForm.submit();">
+<input type="button" value="\$Lang->{Stop_Dequeue_Backup}"
+ onClick="document.StartStopForm.action.value='Stop_Dequeue_Backup';
+          document.StartStopForm.submit();">
 </form>
 \${h2("Prospetto backup")}
 <p>
-Cliccare sul numero di bakcup per sfogliare e ripristinare i file di backup.
+Cliccare sul numero di backup per sfogliare e ripristinare i file di backup.
 </p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Numero backup </td>
     <td align="center"> Tipo </td>
     <td align="center"> Completo </td>
+    <td align="center"> Livello </td>
     <td align="center"> Data avvio </td>
     <td align="center"> Durata (minuti) </td>
     <td align="center"> Et&agrave; (giorni) </td>
@@ -686,7 +706,7 @@ riutilizzo e file nuovi.
     <td align="center"> Tipo </td>
     <td align="center"> Numero file </td>
     <td align="center"> Dimensione (MB) </td>
-    <td align="center"> Velocit&agrave (MB/s) </td>
+    <td align="center"> Velocit&agrave; (MB/s) </td>
     <td align="center"> Numero file </td>
     <td align="center"> Dimensione (MB) </td>
     <td align="center"> Numero file </td>
@@ -732,11 +752,16 @@ $Lang{Host__host_Archive_Summary2} = <<EOF;
 
 \${h2("Azioni utente")}
 <p>
-<form action="\$MyURL" method="get">
+<form name="StartStopForm" action="\$MyURL" method="get">
 <input type="hidden" name="archivehost" value="\$host">
 <input type="hidden" name="host" value="\$host">
-<input type="submit" value="$Lang{Start_Archive}" name="action">
-<input type="submit" value="$Lang{Stop_Dequeue_Archive}" name="action">
+<input type="hidden" name="action" value="">
+<input type="button" value="\$Lang->{Start_Archive}"
+ onClick="document.StartStopForm.action.value='Start_Archive';
+          document.StartStopForm.submit();">
+<input type="button" value="\$Lang->{Stop_Dequeue_Archive}"
+ onClick="document.StartStopForm.action.value='Stop_Dequeue_Archive';
+          document.StartStopForm.submit();">
 </form>
 
 \$ArchiveStr
@@ -806,17 +831,17 @@ $Lang{Backup_browse_for__host} = <<EOF;
 <input type="hidden" name="host" value="\$host">
 <input type="hidden" name="share" value="\${EscHTML(\$share)}">
 <input type="hidden" name="fcbMax" value="\$checkBoxCnt">
-<input type="hidden" name="action" value="$Lang{Restore}">
+<input type="hidden" name="action" value="Restore">
 <br>
 <table width="100%">
-<tr><td valign="top">
-    <br><table align="center" border="0" cellpadding="0" cellspacing="0" bgcolor="#ffffff">
+<tr><td valign="top" width="30%">
+    <table align="left" border="0" cellpadding="0" cellspacing="0" bgcolor="#ffffff">
     \$dirStr
     </table>
 </td><td width="3%">
 </td><td valign="top">
     <br>
-        <table border="0" width="100%" align="left" cellpadding="3" cellspacing="1">
+        <table border width="100%" align="left" cellpadding="3" cellspacing="1">
         \$fileHeader
         \$topCheckAll
         \$fileStr
@@ -863,7 +888,7 @@ Questa videata mostra tutte le versioni uniche disponibili nei diversi backup:
 \${h2("Cronologia di \${EscHTML(\$dirDisplay)}")}
 
 <br>
-<table cellspacing="2" cellpadding="3">
+<table border cellspacing="2" cellpadding="3">
 <tr class="fviewheader"><td>Numero backup</td>\$backupNumStr</tr>
 <tr class="fviewheader"><td>Data backup</td>\$backupTimeStr</tr>
 \$fileStr
@@ -891,7 +916,7 @@ $Lang{Restore___num_details_for__host2} = <<EOF;
 <tr><td class="tableheader"> Durata </td><td class="border"> \$duration min </td></tr>
 <tr><td class="tableheader"> Numero file </td><td class="border"> \$Restores[\$i]{nFiles} </td></tr>
 <tr><td class="tableheader"> Dimensione totale </td><td class="border"> \${MB}MB </td></tr>
-<tr><td class="tableheader"> Tasso trasferimento </td><td class="border"> \$MBperSecMB/s </td></tr>
+<tr><td class="tableheader"> Tasso trasferimento </td><td class="border"> \${MBperSec}MB/s </td></tr>
 <tr><td class="tableheader"> Errori creazione tar </td><td class="border"> \$Restores[\$i]{tarCreateErrs} </td></tr>
 <tr><td class="tableheader"> Errori trasferimento </td><td class="border"> \$Restores[\$i]{xferErrs} </td></tr>
 <tr><td class="tableheader"> File log trasferimento </td><td class="border">
@@ -915,13 +940,13 @@ $Lang{Archive___num_details_for__host2 } = <<EOF;
 \${h1("Dettagli archivio n. \$num per \$host")}
 <p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
-<tr><td class="tableheader"> Number </td><td class="border"> \$Archives[\$i]{num} </td></tr>
-<tr><td class="tableheader"> Requested by </td><td class="border"> \$ArchiveReq{user} </td></tr>
-<tr><td class="tableheader"> Request time </td><td class="border"> \$reqTime </td></tr>
-<tr><td class="tableheader"> Result </td><td class="border"> \$Archives[\$i]{result} </td></tr>
-<tr><td class="tableheader"> Error Message </td><td class="border"> \$Archives[\$i]{errorMsg} </td></tr>
-<tr><td class="tableheader"> Start time </td><td class="border"> \$startTime </td></tr>
-<tr><td class="tableheader"> Duration </td><td class="border"> \$duration\' </td></tr>
+<tr><td class="tableheader"> Numero </td><td class="border"> \$Archives[\$i]{num} </td></tr>
+<tr><td class="tableheader"> Richiesto da </td><td class="border"> \$ArchiveReq{user} </td></tr>
+<tr><td class="tableheader"> Data richiesta </td><td class="border"> \$reqTime </td></tr>
+<tr><td class="tableheader"> Risultato </td><td class="border"> \$Archives[\$i]{result} </td></tr>
+<tr><td class="tableheader"> Messaggio d\'errore </td><td class="border"> \$Archives[\$i]{errorMsg} </td></tr>
+<tr><td class="tableheader"> Data inizio </td><td class="border"> \$startTime </td></tr>
+<tr><td class="tableheader"> Durata </td><td class="border"> \$duration\' </td></tr>
 <tr><td class="tableheader"> Xfer log file </td><td class="border">
 <a href="\$MyURL?action=view&type=ArchiveLOG&num=\$Archives[\$i]{num}&host=\$host">Visualizza</a>,
 <a href="\$MyURL?action=view&type=ArchiveErr&num=\$Archives[\$i]{num}&host=\$host">Errori</a>
@@ -973,8 +998,8 @@ $Lang{Nice_try__but_you_can_t_put} = "Bella mossa, man non &egrave; possibile me
 $Lang{Host__doesn_t_exist} = "L\'host \${EscHTML(\$In{hostDest})} non esiste";
 $Lang{You_don_t_have_permission_to_restore_onto_host} = "Non si possiedono i permessi per ripristinare sull\'host"
 		    . " \${EscHTML(\$In{hostDest})}";
-$Lang{Can_t_open_create} = "Impossibile creare/aprire "
-                    . "\${EscHTML(\"\$TopDir/pc/\$hostDest/\$reqFileName\")}";
+$Lang{Can_t_open_create__openPath} = "Impossibile creare/aprire "
+		. "\${EscHTML(\"\$openPath\")}";
 $Lang{Only_privileged_users_can_restore_backup_files2} = "Solo gli utenti privilegiati possono ripristinare i file"
                 . " per l\'host \${EscHTML(\$host)}.";
 $Lang{Empty_host_name} = "Nome host vuoto";
@@ -1022,7 +1047,7 @@ $Lang{LOG_files} = "File log";
 $Lang{Old_LOGs} = "Vecchi log";
 $Lang{Email_summary} = "Prospetto email";
 $Lang{Config_file} = "File configurazione";
-$Lang{Hosts_file} = "File host";
+# $Lang{Hosts_file} = "File host";
 $Lang{Current_queues} = "Code correnti";
 $Lang{Documentation} = "Documentazione";
 
@@ -1060,7 +1085,7 @@ EOF
 
 # ---------
 $Lang{A_command_for_host_is_on_the_command_queue_will_run_soon} = <<EOF;
-<li>&Egrave gi&agrave; presente un comando per \$host nella coda dei comandi (sar&agrave; eseguito a breve).
+<li>&Egrave; gi&agrave; presente un comando per \$host nella coda dei comandi (sar&agrave; eseguito a breve).
 EOF
 
 # --------
@@ -1096,7 +1121,7 @@ $Lang{__time0_to__time1_on__days} = "\$t0 alle \$t1 di \$days";
 
 $Lang{Backups_are_deferred_for_hours_hours_change_this_number} = <<EOF;
 <li>I backup sono stati posticipati per \$hours ore
-(<a href=\"\$MyURL?action=\${EscURI(\$Lang->{Stop_Dequeue_Archive})}&host=\$host\">modifica questo numero</a>).
+(<a href=\"\$MyURL?action=Stop_Dequeue_Backup&host=\$host\">modifica questo numero</a>).
 EOF
 
 $Lang{tryIP} = " e \$StatusHost{dhcpHostIP}";
@@ -1218,6 +1243,8 @@ $Lang{Reason_no_ping}        = "no ping";
 $Lang{Reason_backup_canceled_by_user}  = "backup annullato dall\'utente";
 $Lang{Reason_restore_canceled_by_user} = "ripristino annullato dall\'utente";
 $Lang{Reason_archive_canceled_by_user} = "archivio annullato dall\'utente";
+$Lang{Disabled_OnlyManualBackups}  = "auto disabilitato";  
+$Lang{Disabled_AllBackupsDisabled} = "disabilitato";                  
 
 # ---------
 # Email messages
@@ -1227,7 +1254,7 @@ $Lang{EMailNoBackupEverSubj} = "BackupPC: nessun backup riuscito per \$host";
 $Lang{EMailNoBackupEverMesg} = <<'EOF';
 To: $user$domain
 Subject: $subj
-
+$headers
 Ciao $userName,
 
 Il nostro software di backup non e` ancora riuscito ad effettuare un
@@ -1256,7 +1283,7 @@ $Lang{EMailNoBackupRecentSubj} = "BackupPC: non ci sono backup recenti per \$hos
 $Lang{EMailNoBackupRecentMesg} = <<'EOF';
 To: $user$domain
 Subject: $subj
-
+$headers
 Ciao $userName,
 
 non e` stato effettuato correttamente il backup del tuo PC ($host) per
@@ -1285,7 +1312,7 @@ $Lang{EMailOutlookBackupSubj} = "BackupPC: i file di Outlook su \$host richiedon
 $Lang{EMailOutlookBackupMesg} = <<'EOF';
 To: $user$domain
 Subject: $subj
-
+$headers
 Ciao $userName,
 
 Il backup dei file di Outlook presenti sul tuo PC $howLong.
@@ -1316,3 +1343,136 @@ EOF
 
 $Lang{howLong_not_been_backed_up} = "non e` riuscito";
 $Lang{howLong_not_been_backed_up_for_days_days} = "risale a \$days giorni fa";
+
+#######################################################################
+# RSS strings
+#######################################################################
+$Lang{RSS_Doc_Title}       = "BackupPC Server";
+$Lang{RSS_Doc_Description} = "RSS feed for BackupPC";
+$Lang{RSS_Host_Summary}    = <<EOF;
+Completi: \$fullCnt;
+Et&agrave; completi (giorni): \$fullAge;
+Dimensione completi (GB): \$fullSize;
+Velocit&agrave; (MB/s): \$fullRate;
+Incrementali: \$incrCnt;
+Et&agrave; incrementali (giorni): \$incrAge;
+Stato: \$host_state;
+Ultimo tentativo: \$host_last_attempt;
+EOF
+
+#######################################################################
+# Configuration editor strings
+#######################################################################
+
+$Lang{Only_privileged_users_can_edit_config_files} = "Solo gli utenti privilegiati possono modificare la configurazione.";
+$Lang{CfgEdit_Edit_Config} = "Modifica Configurazione";
+$Lang{CfgEdit_Edit_Hosts}  = "Modifica Hosts";
+
+$Lang{CfgEdit_Title_Server} = "Server";
+$Lang{CfgEdit_Title_General_Parameters} = "Parametri Generali";
+$Lang{CfgEdit_Title_Wakeup_Schedule} = "Pianificazione Esecuzioni";
+$Lang{CfgEdit_Title_Concurrent_Jobs} = "Lavori Contemporanei";
+$Lang{CfgEdit_Title_Pool_Filesystem_Limits} = "Limiti del Pool Filesystem";
+$Lang{CfgEdit_Title_Other_Parameters} = "Altri parametri";
+$Lang{CfgEdit_Title_Remote_Apache_Settings} = "Configurazione Apache Remota";
+$Lang{CfgEdit_Title_Program_Paths} = "Percorsi Dei programmi";
+$Lang{CfgEdit_Title_Install_Paths} = "Percorsi Di Installazione";
+$Lang{CfgEdit_Title_Email} = "Email";
+$Lang{CfgEdit_Title_Email_settings} = "Configurazione Email";
+$Lang{CfgEdit_Title_Email_User_Messages} = "Messaggi Email Utente";
+$Lang{CfgEdit_Title_CGI} = "CGI";
+$Lang{CfgEdit_Title_Admin_Privileges} = "Privilegi Admin";
+$Lang{CfgEdit_Title_Page_Rendering} = "Visualizzazione Pagina";
+$Lang{CfgEdit_Title_Paths} = "Percorsi";
+$Lang{CfgEdit_Title_User_URLs} = "URL Utenti";
+$Lang{CfgEdit_Title_User_Config_Editing} = "Modifica Configurazione Utenti";
+$Lang{CfgEdit_Title_Xfer} = "Xfer";
+$Lang{CfgEdit_Title_Xfer_Settings} = "Configurazione Xfer";
+$Lang{CfgEdit_Title_Smb_Settings} = "Configurazione Smb";
+$Lang{CfgEdit_Title_Tar_Settings} = "Configurazione Tar";
+$Lang{CfgEdit_Title_Rsync_Settings} = "Configurazione Rsync";
+$Lang{CfgEdit_Title_Rsyncd_Settings} = "Configurazione Rsyncd";
+$Lang{CfgEdit_Title_BackupPCd_Settings} = "Configurazione BackupPCd";
+$Lang{CfgEdit_Title_Archive_Settings} = "Configurazione Archivi";
+$Lang{CfgEdit_Title_Include_Exclude} = "Includi/Escludi";
+$Lang{CfgEdit_Title_Smb_Paths_Commands} = "Smb Percorsi/Comandi";
+$Lang{CfgEdit_Title_Tar_Paths_Commands} = "Tar Percorsi/Comandi";
+$Lang{CfgEdit_Title_Rsync_Paths_Commands_Args} = "Rsync Percorsi/Comandi/Argomenti";
+$Lang{CfgEdit_Title_Rsyncd_Port_Args} = "Rsyncd Porta/Argomenti";
+$Lang{CfgEdit_Title_Archive_Paths_Commands} = "Archivi Percorsi/Comandi";
+$Lang{CfgEdit_Title_Schedule} = "Pianificazione";
+$Lang{CfgEdit_Title_Full_Backups} = "Backup Completi";
+$Lang{CfgEdit_Title_Incremental_Backups} = "Backup Incrementali";
+$Lang{CfgEdit_Title_Blackouts} = "Blackouts";
+$Lang{CfgEdit_Title_Other} = "Altro";
+$Lang{CfgEdit_Title_Backup_Settings} = "Configurazione Backup";
+$Lang{CfgEdit_Title_Client_Lookup} = "Client Lookup";
+$Lang{CfgEdit_Title_Other} = "Altro";
+$Lang{CfgEdit_Title_User_Commands} = "Comandi Utente";
+$Lang{CfgEdit_Title_Hosts} = "Hosts";
+
+$Lang{CfgEdit_Hosts_Comment} = <<EOF;
+Per aggiungere un nuovo host, seleziona Aggiungi e inserisci il nome. 
+Per aggiungere un nuovo host partendo dalla configurazione di un altro
+host, inserisci il nome dell\'host con il formato NUOVOHOST=HOSTDACOPIARE.
+Questo sovrascriver&aacute; qualsiasi eventuale configurazione per il
+NUOVOHOST. Puoi dunque fare ci&oacute; anche per un host esistente.
+Per cancellare un host, clicca su Cancella. Quando Aggiungi, Cancelli,
+o copi la configurazione di un host, i cambiamenti vengono salvati
+solo dopo aver cliccato su Salva. I backup degli host cancellati
+non saranno rimossi, quindi se accidentalmente cancelli un host
+puoi semplicemente riaggiungerlo. Per cancellare definitivamente i
+backup di un host, dovrai quindi cancellare manualmente i file in
+\$topDir/pc/HOST
+EOF
+
+$Lang{CfgEdit_Header_Main} = <<EOF;
+\${h1("Editor Configurazione Principale")}
+EOF
+
+$Lang{CfgEdit_Header_Host} = <<EOF;
+\${h1("Editor Configurazione Host \$host")}
+<p>
+Nota: Se vuoi modificare un valore specifico per questo host, seleziona Sovrascrivi.
+<p>
+EOF
+
+$Lang{CfgEdit_Button_Save}     = "Salva";
+$Lang{CfgEdit_Button_Insert}   = "Inserisci";
+$Lang{CfgEdit_Button_Delete}   = "Cancella";
+$Lang{CfgEdit_Button_Add}      = "Aggiungi";
+$Lang{CfgEdit_Button_Override} = "Sovrascrivi";
+$Lang{CfgEdit_Button_New_Key}  = "Nuova chiave";
+
+$Lang{CfgEdit_Error_No_Save}
+            = "Errore: Non salvo poich&eacute; sono presenti errori";
+$Lang{CfgEdit_Error__must_be_an_integer}
+            = "Errore: \$var deve essere un numero intero";
+$Lang{CfgEdit_Error__must_be_real_valued_number}
+            = "Errore: \$var deve esser un numero con un valore reale";
+$Lang{CfgEdit_Error__entry__must_be_an_integer}
+            = "Errore: \$var entry \$k deve essere un numero intero";
+$Lang{CfgEdit_Error__entry__must_be_real_valued_number}
+            = "Errore: \$var entry \$k deve esser un numero con un valore reale";
+$Lang{CfgEdit_Error__must_be_executable_program}
+            = "Errore: \$var deve essere un percorso valido";
+$Lang{CfgEdit_Error__must_be_valid_option}
+            = "Errore: \$var deve essere una opzione valida";
+$Lang{CfgEdit_Error_Copy_host_does_not_exist}
+            = "L\'host da copiare \$copyHost non esiste; creo dunque l\'host \$fullHost da zero.  Se non &egrave; quello che desideravi, cancella questo host.";
+
+$Lang{CfgEdit_Log_Copy_host_config}
+            = "\$User ha copiato la configurazione di \$fromHost su \$host\n";
+$Lang{CfgEdit_Log_Delete_param}
+            = "\$User ha cancellato  \$p da \$conf\n";
+$Lang{CfgEdit_Log_Add_param_value}
+            = "\$User ha aggiunto \$p a \$conf, settandolo a \$value\n";
+$Lang{CfgEdit_Log_Change_param_value}
+            = "\$User ha cambiato \$p su \$conf in \$valueNew da \$valueOld\n";
+$Lang{CfgEdit_Log_Host_Delete}
+            = "\$User ha cancellato l\'host \$host\n";
+$Lang{CfgEdit_Log_Host_Change}
+            = "\$User host \$host ha cambiato \$key da \$valueOld in \$valueNew\n";
+$Lang{CfgEdit_Log_Host_Add}
+            = "\$User ha aggiunto l\'host \$host: \$value\n";
+
