@@ -31,7 +31,7 @@
 #
 #========================================================================
 #
-# Version 2.1.2, released 5 Sep 2005.
+# Version 3.0.0, released 28 Jan 2007.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -140,7 +140,7 @@ sub dirCache
 	    }
 	}
         foreach my $file ( @dir ) {
-            $file = $1 if ( $file =~ /(.*)/ );
+            $file = $1 if ( $file =~ /(.*)/s );
             my $fileUM = $file;
             $fileUM = $m->{bpc}->fileNameUnmangle($fileUM) if ( $mangle );
             #print(STDERR "Doing $fileUM\n");
@@ -150,6 +150,7 @@ sub dirCache
             next if ( defined($m->{files}{$fileUM})
 		    || $file eq ".."
 		    || $file eq "."
+		    || $file eq "backupInfo"
 		    || $mangle && $file eq "attrib" );
 	    #
 	    # skip directories in earlier backups (each backup always
@@ -248,10 +249,12 @@ sub shareList
     my @dir = readdir(DIR);
     closedir(DIR);
     foreach my $file ( @dir ) {
-        $file = $1 if ( $file =~ /(.*)/ );
+        $file = $1 if ( $file =~ /(.*)/s );
         next if ( $file eq "attrib" && $mangle
                || $file eq "."
-               || $file eq ".." );
+               || $file eq ".."
+               || $file eq "backupInfo"
+            );
         my $fileUM = $file;
         $fileUM = $m->{bpc}->fileNameUnmangle($fileUM) if ( $mangle );
         push(@shareList, $fileUM);
@@ -286,7 +289,7 @@ sub fileAttrib
     my($m, $backupNum, $share, $path) = @_;
 
     #print(STDERR "fileAttrib($backupNum, $share, $path)\n");
-    if ( $path =~ s{(.*)/+(.+)}{$1} ) {
+    if ( $path =~ s{(.*)/+(.+)}{$1}s ) {
         my $file = $2;
         $m->dirCache($backupNum, $share, $path);
         return $m->{files}{$file};
@@ -398,7 +401,7 @@ sub dirHistory
 	    }
 	}
         foreach my $file ( @dir ) {
-            $file = $1 if ( $file =~ /(.*)/ );
+            $file = $1 if ( $file =~ /(.*)/s );
             my $fileUM = $file;
             $fileUM = $m->{bpc}->fileNameUnmangle($fileUM) if ( $mangle );
             #print(STDERR "Doing $fileUM\n");
@@ -455,6 +458,17 @@ sub dirHistory
 	    $files->{$fileUM}[$i]{inode}       = $s[1];
         }
 
+	#
+	# Flag deleted files
+	#
+	if ( defined($attr) ) {
+	    my $a = $attr->get;
+	    foreach my $fileUM ( keys(%$a) ) {
+		next if ( $a->{$fileUM}{type} != BPC_FTYPE_DELETED );
+		$files->{$fileUM}[$i]{type} = BPC_FTYPE_DELETED;
+	    }
+	}
+
 	#
 	# Merge old backups.  Don't merge directories from old
 	# backups because every backup has an accurate directory
@@ -470,18 +484,19 @@ sub dirHistory
 		$files->{$fileUM}[$i] = $files->{$fileUM}[$k];
 	    }
 	}
-
-	#
-	# Finally, remove deleted files
-	#
-	if ( defined($attr) ) {
-	    my $a = $attr->get;
-	    foreach my $fileUM ( keys(%$a) ) {
-		next if ( $a->{$fileUM}{type} != BPC_FTYPE_DELETED );
-		$files->{$fileUM}[$i] = undef if ( defined($files->{$fileUM}) );
-	    }
-	}
     }
+
+    #
+    # Remove deleted files
+    #
+    for ( $i = 0 ; $i < @{$m->{backups}} ; $i++ ) {
+        foreach my $fileUM ( keys(%$files) ) {
+            next if ( !defined($files->{$fileUM}[$i])
+                    || $files->{$fileUM}[$i]{type} != BPC_FTYPE_DELETED );
+            $files->{$fileUM}[$i] = undef;
+        }
+    }
+
     #print STDERR "Returning:\n", Dumper($files);
     return $files;
 }
