@@ -29,7 +29,7 @@
 #
 #========================================================================
 #
-# Version 2.1.2, released 5 Sep 2005.
+# Version 3.0.0, released 28 Jan 2007.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -40,6 +40,7 @@ package BackupPC::Xfer::Rsync;
 use strict;
 use BackupPC::View;
 use BackupPC::Xfer::RsyncFileIO;
+use Encode qw/from_to encode/;
 
 use vars qw( $RsyncLibOK $RsyncLibErr );
 
@@ -55,10 +56,10 @@ BEGIN {
 	#
 	# Note: also update configure.pl when this version number is changed!
 	#
-        if ( $File::RsyncP::VERSION < 0.52 ) {
+        if ( $File::RsyncP::VERSION < 0.68 ) {
             $RsyncLibOK = 0;
             $RsyncLibErr = "File::RsyncP module version"
-                         . " ($File::RsyncP::VERSION) too old: need 0.52";
+                         . " ($File::RsyncP::VERSION) too old: need 0.68";
         } else {
             $RsyncLibOK = 1;
         }
@@ -130,6 +131,8 @@ sub start
 	$rsyncArgs = $conf->{RsyncRestoreArgs};
 	my $remoteDir = "$t->{shareName}/$t->{pathHdrDest}";
 	$remoteDir    =~ s{//+}{/}g;
+        from_to($remoteDir, "utf8", $conf->{ClientCharset})
+                                    if ( $conf->{ClientCharset} ne "" );
         $argList = ['--server', @$rsyncArgs, '.', $remoteDir];
 	$fioArgs = {
 	    client   => $t->{bkupSrcHost},
@@ -197,9 +200,13 @@ sub start
                 }
             }
             foreach my $file ( @inc ) {
+                $file = encode($conf->{ClientCharset}, $file)
+                            if ( $conf->{ClientCharset} ne "" );
                 push(@fileList, "--include=$file");
             }
             foreach my $file ( @exc ) {
+                $file = encode($conf->{ClientCharset}, $file)
+                            if ( $conf->{ClientCharset} ne "" );
                 push(@fileList, "--exclude=$file");
             }
         }
@@ -209,19 +216,25 @@ sub start
                 #
                 # just append additional exclude lists onto the end
                 #
+                $file = encode($conf->{ClientCharset}, $file)
+                            if ( $conf->{ClientCharset} ne "" );
                 push(@fileList, "--exclude=$file");
             }
         }
         if ( $t->{type} eq "full" ) {
 	    if ( $t->{partialNum} ) {
 		$logMsg = "full backup started for directory $t->{shareName};"
-		        . " updating partial $t->{partialNum}";
+		        . " updating partial #$t->{partialNum}";
 	    } else {
 		$logMsg = "full backup started for directory $t->{shareName}";
+                if ( $t->{incrBaseBkupNum} ne "" ) {
+                    $logMsg .= " (baseline backup #$t->{incrBaseBkupNum})";
+                }
 	    }
         } else {
-            $incrDate = $bpc->timeStamp($t->{lastFull} - 3600, 1);
-            $logMsg = "incr backup started back to $incrDate for directory"
+            $incrDate = $bpc->timeStamp($t->{incrBaseTime}, 1);
+            $logMsg = "incr backup started back to $incrDate"
+                    . " (backup #$t->{incrBaseBkupNum}) for directory"
                     . " $t->{shareName}";
         }
         
@@ -237,12 +250,18 @@ sub start
         $rsyncArgs = [@$rsyncArgs, "--ignore-times"]
                                     if ( $t->{type} eq "full" );
 	$rsyncClientCmd = $conf->{RsyncClientCmd};
+        my $shareNameSlash = $t->{shareNameSlash};
+        from_to($shareNameSlash, "utf8", $conf->{ClientCharset})
+                            if ( $conf->{ClientCharset} ne "" );
         $argList = ['--server', '--sender', @$rsyncArgs,
-                              '.', $t->{shareNameSlash}];
+                              '.', $shareNameSlash];
+	eval {
+	    $argList = File::RsyncP->excludeStrip($argList);
+	};
 	$fioArgs = {
 	    client     => $t->{client},
 	    share      => $t->{shareName},
-	    viewNum    => $t->{lastFullBkupNum},
+	    viewNum    => $t->{incrBaseBkupNum},
             partialNum => $t->{partialNum},
 	};
     }
@@ -260,6 +279,10 @@ sub start
 	sshPath   => $conf->{SshPath},
 	argList   => $argList,
     };
+    from_to($args->{shareName}, "utf8", $conf->{ClientCharset})
+                            if ( $conf->{ClientCharset} ne "" );
+    from_to($args->{shareNameSlash}, "utf8", $conf->{ClientCharset})
+                            if ( $conf->{ClientCharset} ne "" );
     $rsyncClientCmd = $bpc->cmdVarSubstitute($rsyncClientCmd, $args);
 
     #
@@ -300,6 +323,7 @@ sub start
 	pidHandler   => sub {
 			    $t->{pidHandler}(@_);
 			},
+        clientCharset => $conf->{ClientCharset},
 	fio          => BackupPC::Xfer::RsyncFileIO->new({
 			    xfer       => $t,
 			    bpc        => $t->{bpc},
@@ -313,6 +337,7 @@ sub start
 					      $t->{XferLOG}->write(\$str);
 					  },
 			    cacheCheckProb => $conf->{RsyncCsumCacheVerifyProb},
+                            clientCharset  => $conf->{ClientCharset},
 			    %$fioArgs,
 		      }),
     });
@@ -342,6 +367,11 @@ sub run
 	$remoteDir       = $t->{shareNameSlash};
 	$remoteDirDaemon = ".";
     }
+    from_to($remoteDir, "utf8", $conf->{ClientCharset})
+                                if ( $conf->{ClientCharset} ne "" );
+    from_to($remoteDirDaemon, "utf8", $conf->{ClientCharset})
+                                if ( $conf->{ClientCharset} ne "" );
+
     if ( $t->{XferMethod} eq "rsync" ) {
 	#
 	# Run rsync command
@@ -349,6 +379,8 @@ sub run
 	my $str = "Running: "
 	        . $t->{bpc}->execCmd2ShellCmd(@{$t->{rsyncClientCmd}})
 		. "\n";
+        from_to($str, $conf->{ClientCharset}, "utf8")
+                                if ( $conf->{ClientCharset} ne "" );
 	$t->{XferLOG}->write(\$str);
 	$rs->remoteStart($remoteSend, $remoteDir);
     } else {
@@ -369,6 +401,8 @@ sub run
 	#
 	my $module = $t->{shareName};
 	$module = $t->{shareNameSlash} if ( $module =~ /\// );
+        from_to($module, "utf8", $conf->{ClientCharset})
+                                    if ( $conf->{ClientCharset} ne "" );
 	if ( defined(my $err = $rs->serverService($module,
                                              $conf->{RsyncdUserName},
                                              $conf->{RsyncdPasswd},
@@ -381,7 +415,10 @@ sub run
 	}
 	$rs->serverStart($remoteSend, $remoteDirDaemon);
     }
-    my $error = $rs->go($t->{shareNameSlash});
+    my $shareNameSlash = $t->{shareNameSlash};
+    from_to($shareNameSlash, "utf8", $conf->{ClientCharset})
+                                if ( $conf->{ClientCharset} ne "" );
+    my $error = $rs->go($shareNameSlash);
     $rs->serverClose();
 
     #
