@@ -12,7 +12,7 @@
 #
 #========================================================================
 #
-# Version 2.1.2, released 5 Sep 2005.
+# Version 3.0.0, released 28 Jan 2007.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -22,19 +22,21 @@ package BackupPC::Xfer::RsyncFileIO;
 
 use strict;
 use File::Path;
+use Encode qw/from_to/;
 use BackupPC::Attrib qw(:all);
 use BackupPC::View;
 use BackupPC::Xfer::RsyncDigest qw(:all);
 use BackupPC::PoolWrite;
 
-use constant S_IFMT       => 0170000;	# type of file
-use constant S_IFDIR      => 0040000; 	# directory
-use constant S_IFCHR      => 0020000; 	# character special
-use constant S_IFBLK      => 0060000; 	# block special
-use constant S_IFREG      => 0100000; 	# regular
-use constant S_IFLNK      => 0120000; 	# symbolic link
-use constant S_IFSOCK     => 0140000; 	# socket
-use constant S_IFIFO      => 0010000; 	# fifo
+use constant S_HLINK_TARGET => 0400000;    # this file is hardlink target
+use constant S_IFMT         => 0170000;	   # type of file
+use constant S_IFDIR        => 0040000;    # directory
+use constant S_IFCHR        => 0020000;    # character special
+use constant S_IFBLK        => 0060000;    # block special
+use constant S_IFREG        => 0100000;    # regular
+use constant S_IFLNK        => 0120000;    # symbolic link
+use constant S_IFSOCK       => 0140000;    # socket
+use constant S_IFIFO        => 0010000;    # fifo
 
 use vars qw( $RsyncLibOK );
 
@@ -59,7 +61,7 @@ sub new
     my $fio = bless {
         blockSize    => 700,
         logLevel     => 0,
-        digest       => File::RsyncP::Digest->new,
+        digest       => File::RsyncP::Digest->new(),
         checksumSeed => 0,
 	attrib	     => {},
 	logHandler   => \&logHandler,
@@ -74,6 +76,7 @@ sub new
 	%$options,
     }, $class;
 
+    $fio->{digest}->protocol($fio->{protocol_version});
     $fio->{shareM}   = $fio->{bpc}->fileNameEltMangle($fio->{share});
     $fio->{outDir}   = "$fio->{xfer}{outDir}/new/";
     $fio->{outDirSh} = "$fio->{outDir}/$fio->{shareM}/";
@@ -85,6 +88,20 @@ sub new
     return $fio;
 }
 
+#
+# We publish our version to File::RsyncP.  This is so File::RsyncP
+# can provide backward compatibility to older FileIO code.
+#
+# Versions:
+#
+#   undef or 1:  protocol version 26, no hardlinks
+#   2:           protocol version 28, supports hardlinks
+#
+sub version
+{
+    return 2;
+}
+
 sub blockSize
 {
     my($fio, $value) = @_;
@@ -93,6 +110,25 @@ sub blockSize
     return $fio->{blockSize};
 }
 
+sub protocol_version
+{
+    my($fio, $value) = @_;
+
+    if ( defined($value) ) {
+        $fio->{protocol_version} = $value;
+        $fio->{digest}->protocol($fio->{protocol_version});
+    }
+    return $fio->{protocol_version};
+}
+
+sub preserve_hard_links
+{
+    my($fio, $value) = @_;
+
+    $fio->{preserve_hard_links} = $value if ( defined($value) );
+    return $fio->{preserve_hard_links};
+}
+
 sub logHandlerSet
 {
     my($fio, $sub) = @_;
@@ -108,10 +144,11 @@ sub csumStart
     my($fio, $f, $needMD4, $defBlkSize, $phase) = @_;
 
     $defBlkSize ||= $fio->{blockSize};
-    my $attr = $fio->attribGet($f);
+    my $attr = $fio->attribGet($f, 1);
     $fio->{file} = $f;
     $fio->csumEnd if ( defined($fio->{csum}) );
     return -1 if ( $attr->{type} != BPC_FTYPE_FILE );
+
     #
     # Rsync uses short checksums on the first phase.  If the whole-file
     # checksum fails, then the file is repeated with full checksums.
@@ -123,7 +160,8 @@ sub csumStart
         my($err, $d, $blkSize) = BackupPC::Xfer::RsyncDigest->digestStart(
                                      $attr->{fullPath}, $attr->{size}, 0,
                                      $defBlkSize, $fio->{checksumSeed},
-                                     0, $attr->{compress}, 0);
+                                     0, $attr->{compress}, 0,
+                                     $fio->{protocol_version});
         my($isCached, $isInvalid) = $d->isCached;
         if ( $fio->{logLevel} >= 5 ) {
             $fio->log("$attr->{fullPath} verify; cached = $isCached,"
@@ -132,7 +170,8 @@ sub csumStart
         if ( $isCached || $isInvalid ) {
             my $ret = BackupPC::Xfer::RsyncDigest->digestAdd(
                             $attr->{fullPath}, $blkSize,
-                            $fio->{checksumSeed}, 1        # verify
+                            $fio->{checksumSeed}, 1,        # verify
+                            $fio->{protocol_version}
                         );
             if ( $ret != 1 ) {
                 $fio->log("Bad cached digest for $attr->{fullPath} ($ret);"
@@ -148,18 +187,18 @@ sub csumStart
     (my $err, $fio->{csum}, my $blkSize)
          = BackupPC::Xfer::RsyncDigest->digestStart($attr->{fullPath},
 			 $attr->{size}, 0, $defBlkSize, $fio->{checksumSeed},
-			 $needMD4, $attr->{compress}, 1);
-    if ( $fio->{logLevel} >= 5 ) {
-        my($isCached, $invalid) = $fio->{csum}->isCached;
-        $fio->log("$attr->{fullPath} cache = $isCached,"
-                . " invalid = $invalid, phase = $phase");
-    }
+			 $needMD4, $attr->{compress}, 1, $fio->{protocol_version});
     if ( $err ) {
         $fio->log("Can't get rsync digests from $attr->{fullPath}"
                 . " (err=$err, name=$f->{name})");
 	$fio->{stats}{errorCnt}++;
         return -1;
     }
+    if ( $fio->{logLevel} >= 5 ) {
+        my($isCached, $invalid) = $fio->{csum}->isCached;
+        $fio->log("$attr->{fullPath} cache = $isCached,"
+                . " invalid = $invalid, phase = $phase");
+    }
     return $blkSize;
 }
 
@@ -186,7 +225,7 @@ sub readStart
 {
     my($fio, $f) = @_;
 
-    my $attr = $fio->attribGet($f);
+    my $attr = $fio->attribGet($f, 1);
     $fio->{file} = $f;
     $fio->readEnd if ( defined($fio->{fh}) );
     if ( !defined($fio->{fh} = BackupPC::FileZIO->open($attr->{fullPath},
@@ -284,14 +323,16 @@ sub viewCacheDir
 
 sub attribGetWhere
 {
-    my($fio, $f) = @_;
-    my($dir, $fname, $share, $shareM);
+    my($fio, $f, $noCache, $fname) = @_;
+    my($dir, $share, $shareM, $partial, $attr);
 
-    $fname = $f->{name};
-    $fname = "$fio->{xfer}{pathHdrSrc}/$fname"
+    if ( !defined($fname) ) {
+        $fname = $f->{name};
+        $fname = "$fio->{xfer}{pathHdrSrc}/$fname"
 		       if ( defined($fio->{xfer}{pathHdrSrc}) );
+    }
     $fname =~ s{//+}{/}g;
-    if ( $fname =~ m{(.*)/(.*)} ) {
+    if ( $fname =~ m{(.*)/(.*)}s ) {
 	$shareM = $fio->{shareM};
 	$dir = $1;
 	$fname = $2;
@@ -304,31 +345,72 @@ sub attribGetWhere
 	$dir = "";
 	$fname = $fio->{share};
     }
-    $fio->viewCacheDir($share, $dir);
     $shareM .= "/$dir" if ( $dir ne "" );
-    if ( defined(my $attr = $fio->{viewCache}{$shareM}{$fname}) ) {
-        return ($attr, 0);
-    } elsif ( defined(my $attr = $fio->{partialCache}{$shareM}{$fname}) ) {
-        return ($attr, 1);
+
+    if ( $noCache ) {
+        $share  = $fio->{share} if ( !defined($share) );
+        my $dirAttr = $fio->{view}->dirAttrib($fio->{viewNum}, $share, $dir);
+        $attr = $dirAttr->{$fname};
     } else {
-        return;
+        $fio->viewCacheDir($share, $dir);
+        if ( defined($attr = $fio->{viewCache}{$shareM}{$fname}) ) {
+            $partial = 0;
+        } elsif ( defined($attr = $fio->{partialCache}{$shareM}{$fname}) ) {
+            $partial = 1;
+        } else {
+            return;
+        }
+        if ( $attr->{mode} & S_HLINK_TARGET ) {
+            $attr->{hlink_self} = 1;
+            $attr->{mode} &= ~S_HLINK_TARGET;
+        }
     }
+    return ($attr, $partial);
 }
 
 sub attribGet
 {
-    my($fio, $f) = @_;
+    my($fio, $f, $doHardLink) = @_;
 
     my($attr) = $fio->attribGetWhere($f);
+    if ( $doHardLink && $attr->{type} == BPC_FTYPE_HARDLINK ) {
+        $fio->log("$attr->{fullPath}: opening for hardlink read"
+                . " (name = $f->{name})") if ( $fio->{logLevel} >= 4 );
+        my $fh = BackupPC::FileZIO->open($attr->{fullPath}, 0,
+                                         $attr->{compress});
+        my $target;
+        if ( defined($fh) ) {
+            $fh->read(\$target,  65536);
+            $fh->close;
+            $target =~ s/^\.?\/+//;
+        } else {
+            $fio->log("$attr->{fullPath}: can't open for hardlink read");
+            $fio->{stats}{errorCnt}++;
+            $attr->{type} = BPC_FTYPE_FILE;
+            return $attr;
+        }
+        $target = "/$target" if ( $target !~ /^\// );
+        $fio->log("$attr->{fullPath}: redirecting to $target")
+                                    if ( $fio->{logLevel} >= 4 );
+        $target =~ s{^/+}{};
+        ($attr) = $fio->attribGetWhere($f, 1, $target);
+        $fio->log(" ... now got $attr->{fullPath}")
+                            if ( $fio->{logLevel} >= 4 );
+    }
     return $attr;
 }
 
 sub mode2type
 {
-    my($fio, $mode) = @_;
+    my($fio, $f) = @_;
+    my $mode = $f->{mode};
 
     if ( ($mode & S_IFMT) == S_IFREG ) {
-	return BPC_FTYPE_FILE;
+        if ( defined($f->{hlink}) && !$f->{hlink_self} ) {
+            return BPC_FTYPE_HARDLINK;
+        } else {
+            return BPC_FTYPE_FILE;
+        }
     } elsif ( ($mode & S_IFMT) == S_IFDIR ) {
 	return BPC_FTYPE_DIR;
     } elsif ( ($mode & S_IFMT) == S_IFLNK ) {
@@ -354,7 +436,7 @@ sub attribSet
     my($fio, $f, $placeHolder) = @_;
     my($dir, $file);
 
-    if ( $f->{name} =~ m{(.*)/(.*)} ) {
+    if ( $f->{name} =~ m{(.*)/(.*)}s ) {
 	$file = $2;
 	$dir  = "$fio->{shareM}/" . $1;
     } elsif ( $f->{name} eq "." ) {
@@ -389,9 +471,12 @@ sub attribSet
     }
     $fio->log("attribSet(dir=$dir, file=$file)") if ( $fio->{logLevel} >= 4 );
 
+    my $mode = $f->{mode};
+
+    $mode |= S_HLINK_TARGET if ( $f->{hlink_self} );
     $fio->{attrib}{$dir}->set($file, {
-                            type  => $fio->mode2type($f->{mode}),
-                            mode  => $f->{mode},
+                            type  => $fio->mode2type($f),
+                            mode  => $mode,
                             uid   => $f->{uid},
                             gid   => $f->{gid},
                             size  => $placeHolder ? -1 : $f->{size},
@@ -405,6 +490,11 @@ sub attribWrite
     my($fio, $d) = @_;
     my($poolWrite);
 
+    #
+    # Don't write attributes on 2nd phase - they're already
+    # taken care of during the first phase.
+    #
+    return if ( $fio->{phase} > 0 );
     if ( !defined($d) ) {
         #
         # flush all entries (in reverse order)
@@ -426,7 +516,7 @@ sub attribWrite
 	my $dir;
 	my $share;
 
-	$dir = $1 if ( $d =~ m{.+?/(.*)} );
+	$dir = $1 if ( $d =~ m{.+?/(.*)}s );
 	$fio->viewCacheDir(undef, $dir);
 	##print("attribWrite $d,$dir\n");
 	##$Data::Dumper::Indent = 1;
@@ -438,7 +528,7 @@ sub attribWrite
 	if ( defined($fio->{viewCache}{$d}) ) {
 	    foreach my $f ( keys(%{$fio->{viewCache}{$d}}) ) {
 		my $name = $f;
-		$name = "$1/$name" if ( $d =~ m{.*?/(.*)} );
+		$name = "$1/$name" if ( $d =~ m{.*?/(.*)}s );
 		if ( defined(my $a = $fio->{attrib}{$d}->get($f)) ) {
 		    #
 		    # delete temporary attributes (skipped files)
@@ -448,7 +538,8 @@ sub attribWrite
 			$fio->logFileAction("skip", {
 				    %{$fio->{viewCache}{$d}{$f}},
 				    name => $name,
-				}) if ( $fio->{logLevel} >= 2 );
+				}) if ( $fio->{logLevel} >= 2
+                                      && $a->{type} == BPC_FTYPE_FILE );
 		    }
 		} elsif ( !$fio->{full} ) {
 		    ##print("Delete file $f\n");
@@ -473,7 +564,7 @@ sub attribWrite
 	my $dirM = $d;
 
 	$dirM = $1 . "/" . $fio->{bpc}->fileNameMangle($2)
-			if ( $dirM =~ m{(.*?)/(.*)} );
+			if ( $dirM =~ m{(.*?)/(.*)}s );
         my $fileName = $fio->{attrib}{$d}->fileName("$fio->{outDir}$dirM");
 	$fio->log("attribWrite(dir=$d) -> $fileName")
 				if ( $fio->{logLevel} >= 4 );
@@ -523,7 +614,7 @@ sub statsGet
 sub makePath
 {
     my($fio, $f) = @_;
-    my $name = $1 if ( $f->{name} =~ /(.*)/ );
+    my $name = $1 if ( $f->{name} =~ /(.*)/s );
     my $path;
 
     if ( $name eq "." ) {
@@ -533,7 +624,7 @@ sub makePath
     }
     $fio->logFileAction("create", $f) if ( $fio->{logLevel} >= 1 );
     $fio->log("makePath($path, 0777)") if ( $fio->{logLevel} >= 5 );
-    $path = $1 if ( $path =~ /(.*)/ );
+    $path = $1 if ( $path =~ /(.*)/s );
     File::Path::mkpath($path, 0, 0777) if ( !-d $path );
     return $fio->attribSet($f) if ( -d $path );
     $fio->log("Can't create directory $path");
@@ -547,23 +638,38 @@ sub makePath
 sub makeSpecial
 {
     my($fio, $f) = @_;
-    my $name = $1 if ( $f->{name} =~ /(.*)/ );
+    my $name = $1 if ( $f->{name} =~ /(.*)/s );
     my $fNameM = $fio->{bpc}->fileNameMangle($name);
     my $path = $fio->{outDirSh} . $fNameM;
     my $attr = $fio->attribGet($f);
     my $str = "";
-    my $type = $fio->mode2type($f->{mode});
+    my $type = $fio->mode2type($f);
 
     $fio->log("makeSpecial($path, $type, $f->{mode})")
 		    if ( $fio->{logLevel} >= 5 );
     if ( $type == BPC_FTYPE_CHARDEV || $type == BPC_FTYPE_BLOCKDEV ) {
 	my($major, $minor, $fh, $fileData);
 
-	$major = $f->{rdev} >> 8;
-	$minor = $f->{rdev} & 0xff;
+        if ( defined($f->{rdev_major}) ) {
+            $major = $f->{rdev_major};
+            $minor = $f->{rdev_minor};
+        } else {
+            $major = $f->{rdev} >> 8;
+            $minor = $f->{rdev} & 0xff;
+        }
         $str = "$major,$minor";
     } elsif ( ($f->{mode} & S_IFMT) == S_IFLNK ) {
         $str = $f->{link};
+    } elsif ( ($f->{mode} & S_IFMT) == S_IFREG ) {
+        #
+        # this is a hardlink
+        #
+        if ( !defined($f->{hlink}) ) {
+            $fio->log("Error: makeSpecial($path, $type, $f->{mode}) called"
+                    . " on a regular non-hardlink file");
+            return 1;
+        }
+        $str  = $f->{hlink};
     }
     #
     # Now see if the file is different, or this is a full, in which
@@ -572,12 +678,13 @@ sub makeSpecial
     my($fh, $fileData);
     if ( $fio->{full}
             || !defined($attr)
-            || $attr->{type}  != $fio->mode2type($f->{mode})
-            || $attr->{mtime} != $f->{mtime}
-            || $attr->{size}  != $f->{size}
-            || $attr->{uid}   != $f->{uid}
-            || $attr->{gid}   != $f->{gid}
-            || $attr->{mode}  != $f->{mode}
+            || $attr->{type}       != $type
+            || $attr->{mtime}      != $f->{mtime}
+            || $attr->{size}       != $f->{size}
+            || $attr->{uid}        != $f->{uid}
+            || $attr->{gid}        != $f->{gid}
+            || $attr->{mode}       != $f->{mode}
+            || $attr->{hlink_self} != $f->{hlink_self}
             || !defined($fh = BackupPC::FileZIO->open($attr->{fullPath}, 0,
                                                       $attr->{compress}))
             || $fh->read(\$fileData, length($str) + 1) != length($str)
@@ -597,6 +704,22 @@ sub makeSpecial
     $fh->close if ( defined($fh) );
 }
 
+#
+# Make a hardlink.  Returns non-zero on error.
+# This actually gets called twice for each hardlink.
+# Once as the file list is processed, and again at
+# the end.  BackupPC does them as it goes (since it is
+# just saving the hardlink info and not actually making
+# hardlinks).
+#
+sub makeHardLink
+{
+    my($fio, $f, $end) = @_;
+
+    return if ( $end );
+    return $fio->makeSpecial($f) if ( !$f->{hlink_self} );
+}
+
 sub unlink
 {
     my($fio, $path) = @_;
@@ -636,6 +759,15 @@ sub logFileAction
     my $owner = "$f->{uid}/$f->{gid}";
     my $type  = (("", "p", "c", "", "d", "", "b", "", "", "", "l", "", "s"))
 		    [($f->{mode} & S_IFMT) >> 12];
+    my $name = $f->{name};
+
+    if ( ($f->{mode} & S_IFMT) == S_IFLNK ) {
+        $name .= " -> $f->{link}";
+    } elsif ( ($f->{mode} & S_IFMT) == S_IFREG
+            && defined($f->{hlink}) && !$f->{hlink_self} ) {
+        $name .= " -> $f->{hlink}";
+    }
+    $name =~ s/\n/\\n/g;
 
     $fio->log(sprintf("  %-6s %1s%4o %9s %11.0f %s",
 				$action,
@@ -643,7 +775,7 @@ sub logFileAction
 				$f->{mode} & 07777,
 				$owner,
 				$f->{size},
-				$f->{name}));
+                                $name));
 }
 
 #
@@ -722,6 +854,21 @@ sub fileDeltaRxStart
               . " ($fio->{rxLocalAttr}{compress} vs $fio->{xfer}{compress})")
                     if ( $fio->{logLevel} >= 4 );
     }
+    #
+    # If the local file is a hardlink then no match
+    #
+    if ( defined($fio->{rxLocalAttr})
+	    && $fio->{rxLocalAttr}{type} == BPC_FTYPE_HARDLINK ) {
+        $fio->{rxMatchBlk} = undef;
+        $fio->log("$fio->{rxFile}{name}: no match on hardlinks")
+                                    if ( $fio->{logLevel} >= 4 );
+        my $fCopy;
+        # need to copy since hardlink attribGet overwrites the name
+        %{$fCopy} = %$f;
+        $fio->{rxHLinkAttr} = $fio->attribGet($fCopy, 1); # hardlink attributes
+    } else {
+        delete($fio->{rxHLinkAttr});
+    }
     delete($fio->{rxInFd});
     delete($fio->{rxOutFd});
     delete($fio->{rxDigest});
@@ -764,7 +911,7 @@ sub fileDeltaRxNext
         # need to open an output file where we will build the
         # new version.
         #
-        $fio->{rxFile}{name} =~ /(.*)/;
+        $fio->{rxFile}{name} =~ /(.*)/s;
 	my $rxOutFileRel = "$fio->{shareM}/" . $fio->{bpc}->fileNameMangle($1);
         my $rxOutFile    = $fio->{outDir} . $rxOutFileRel;
         $fio->{rxOutFd}  = BackupPC::PoolWrite->new($fio->{bpc},
@@ -774,7 +921,8 @@ sub fileDeltaRxNext
                         if ( $fio->{logLevel} >= 9 );
         $fio->{rxOutFile} = $rxOutFile;
         $fio->{rxOutFileRel} = $rxOutFileRel;
-        $fio->{rxDigest} = File::RsyncP::Digest->new;
+        $fio->{rxDigest} = File::RsyncP::Digest->new();
+        $fio->{rxDigest}->protocol($fio->{protocol_version});
         $fio->{rxDigest}->add(pack("V", $fio->{checksumSeed}));
     }
     if ( defined($fio->{rxMatchBlk})
@@ -790,12 +938,15 @@ sub fileDeltaRxNext
         my $attr = $fio->{rxLocalAttr};
 	my $fh;
         if ( !defined($fio->{rxInFd}) && !defined($fio->{rxInData}) ) {
+            my $inPath = $attr->{fullPath};
+            $inPath = $fio->{rxHLinkAttr}{fullPath}
+                            if ( defined($fio->{rxHLinkAttr}) );
             if ( $attr->{compress} ) {
                 if ( !defined($fh = BackupPC::FileZIO->open(
-                                                   $attr->{fullPath},
+                                                   $inPath,
                                                    0,
                                                    $attr->{compress})) ) {
-                    $fio->log("Can't open $attr->{fullPath}");
+                    $fio->log("Can't open $inPath");
 		    $fio->{stats}{errorCnt}++;
                     return -1;
                 }
@@ -846,12 +997,12 @@ sub fileDeltaRxNext
                 }
                 $fh->close;
             } else {
-                if ( open(F, "<", $attr->{fullPath}) ) {
+                if ( open(F, "<", $inPath) ) {
 		    binmode(F);
                     $fio->{rxInFd} = *F;
                     $fio->{rxInName} = $attr->{fullPath};
                 } else {
-                    $fio->log("Unable to open $attr->{fullPath}");
+                    $fio->log("Unable to open $inPath");
 		    $fio->{stats}{errorCnt}++;
                     return -1;
                 }
@@ -864,7 +1015,7 @@ sub fileDeltaRxNext
         my $seekPosn = $fio->{rxMatchBlk} * $fio->{rxBlkSize};
         if ( defined($fio->{rxInFd})
 			&& !sysseek($fio->{rxInFd}, $seekPosn, 0) ) {
-            $fio->log("Unable to seek $attr->{rxInName} to $seekPosn");
+            $fio->log("Unable to seek $fio->{rxInName} to $seekPosn");
 	    $fio->{stats}{errorCnt}++;
             return -1;
         }
@@ -927,11 +1078,12 @@ sub fileDeltaRxNext
 sub fileDeltaRxDone
 {
     my($fio, $md4, $phase) = @_;
-    my $name = $1 if ( $fio->{rxFile}{name} =~ /(.*)/ );
+    my $name = $1 if ( $fio->{rxFile}{name} =~ /(.*)/s );
     my $ret;
 
     close($fio->{rxInFd})  if ( defined($fio->{rxInFd}) );
     unlink("$fio->{outDirSh}RStmp") if  ( -f "$fio->{outDirSh}RStmp" );
+    $fio->{phase} = $phase;
 
     #
     # Check the final md4 digest
@@ -953,7 +1105,8 @@ sub fileDeltaRxDone
                          = BackupPC::Xfer::RsyncDigest->digestStart(
                                  $attr->{fullPath}, $attr->{size},
                                  0, 2048, $fio->{checksumSeed}, 1,
-                                 $attr->{compress}, 1);
+                                 $attr->{compress}, 1,
+                                 $fio->{protocol_version});
                 if ( $err ) {
                     $fio->log("Can't open $attr->{fullPath} for MD4"
                             . " check (err=$err, $name)");
@@ -971,7 +1124,8 @@ sub fileDeltaRxDone
 		#
 		# Empty file; just create an empty file digest
 		#
-		$fio->{rxDigest} = File::RsyncP::Digest->new;
+		$fio->{rxDigest} = File::RsyncP::Digest->new();
+                $fio->{rxDigest}->protocol($fio->{protocol_version});
 		$fio->{rxDigest}->add(pack("V", $fio->{checksumSeed}));
 		$newDigest = $fio->{rxDigest}->digest;
 	    }
@@ -1025,11 +1179,13 @@ sub fileDeltaRxDone
         my $f = $fio->{rxFile};
 	$fio->logFileAction("same", $f) if ( $fio->{logLevel} >= 1 );
         if ( $fio->{full}
-                || $attr->{type}  != $f->{type}
-                || $attr->{mtime} != $f->{mtime}
-                || $attr->{size}  != $f->{size}
-                || $attr->{gid}   != $f->{gid}
-                || $attr->{mode}  != $f->{mode} ) {
+                || $attr->{type}       != $f->{type}
+                || $attr->{mtime}      != $f->{mtime}
+                || $attr->{size}       != $f->{size}
+                || $attr->{uid}        != $f->{uid}
+                || $attr->{gid}        != $f->{gid}
+                || $attr->{mode}       != $f->{mode}
+                || $attr->{hlink_self} != $f->{hlink_self} ) {
             #
             # In the full case, or if the attributes are different,
             # we need to make a link from the previous file and
@@ -1037,22 +1193,38 @@ sub fileDeltaRxDone
             #
             my $rxOutFile = $fio->{outDirSh}
                             . $fio->{bpc}->fileNameMangle($name);
-            if ( !link($attr->{fullPath}, $rxOutFile) ) {
-                $fio->log("Unable to link $attr->{fullPath} to $rxOutFile");
-		$fio->{stats}{errorCnt}++;
-		$ret = -1;
-            } else {
-		#
-		# Cumulate the stats
-		#
-		$fio->{stats}{TotalFileCnt}++;
-		$fio->{stats}{TotalFileSize} += $fio->{rxSize};
-		$fio->{stats}{ExistFileCnt}++;
-		$fio->{stats}{ExistFileSize} += $fio->{rxSize};
-		$fio->{stats}{ExistFileCompSize} += -s $rxOutFile;
-		$fio->{rxFile}{size} = $fio->{rxSize};
-		$ret = $fio->attribSet($fio->{rxFile});
-	    }
+            my($exists, $digest, $origSize, $outSize, $errs)
+                                = BackupPC::PoolWrite::LinkOrCopy(
+                                      $fio->{bpc},
+                                      $attr->{fullPath},
+                                      $attr->{compress},
+                                      $rxOutFile,
+                                      $fio->{xfer}{compress});
+            #
+            # Cumulate the stats
+            #
+            $fio->{stats}{TotalFileCnt}++;
+            $fio->{stats}{TotalFileSize} += $fio->{rxSize};
+            $fio->{stats}{ExistFileCnt}++;
+            $fio->{stats}{ExistFileSize} += $fio->{rxSize};
+            $fio->{stats}{ExistFileCompSize} += -s $rxOutFile;
+            $fio->{rxFile}{size} = $fio->{rxSize};
+            $ret = $fio->attribSet($fio->{rxFile});
+            $fio->log(@$errs) if ( defined($errs) && @$errs );
+
+            if ( !$exists && $outSize > 0 ) {
+                #
+                # the hard link failed, most likely because the target
+                # file has too many links.  We have copied the file
+                # instead, so add this to the new file list.
+                #
+                my $rxOutFileRel = "$fio->{shareM}/"
+                                 . $fio->{bpc}->fileNameMangle($name);
+                $rxOutFileRel =~ s{^/+}{};
+                my $fh = $fio->{newFilesFH};
+                print($fh "$digest $origSize $rxOutFileRel\n")
+                                                if ( defined($fh) );
+            }
         }
     } else {
 	my $exist = $fio->processClose($fio->{rxOutFd},
@@ -1079,11 +1251,15 @@ sub fileListEltSend
     my($a, $fio, $fList, $outputFunc) = @_;
     my $name = $a->{relPath};
     my $n = $name;
-    my $type = $fio->mode2type($a->{mode});
+    my $type = $a->{type};
     my $extraAttribs = {};
 
+    if ( $a->{mode} & S_HLINK_TARGET ) {
+        $a->{hlink_self} = 1;
+        $a->{mode} &= ~S_HLINK_TARGET;
+    }
     $n =~ s/^\Q$fio->{xfer}{pathHdrSrc}//;
-    $fio->log("Sending $name (remote=$n)") if ( $fio->{logLevel} >= 4 );
+    $fio->log("Sending $name (remote=$n) type = $type") if ( $fio->{logLevel} >= 1 );
     if ( $type == BPC_FTYPE_CHARDEV
 	    || $type == BPC_FTYPE_BLOCKDEV
 	    || $type == BPC_FTYPE_SYMLINK ) {
@@ -1108,7 +1284,11 @@ sub fileListEltSend
 		# Note: char/block devices have $a->{size} = 0, so we
 		# can't do an error check on $rdSize.
 		#
-		$extraAttribs = { rdev => $1 * 256 + $2 };
+		$extraAttribs = {
+                    rdev       => $1 * 256 + $2,
+                    rdev_major => $1,
+                    rdev_minor => $2,
+                };
 	    } else {
 		$fio->log("$name: unexpected special file contents $str");
 		$fio->{stats}{errorCnt}++;
@@ -1119,26 +1299,75 @@ sub fileListEltSend
 	    $fio->log("$name: can't open");
 	    $fio->{stats}{errorCnt}++;
 	}
+    } elsif ( $fio->{preserve_hard_links}
+            && ($type == BPC_FTYPE_HARDLINK || $type == BPC_FTYPE_FILE)
+            && ($type == BPC_FTYPE_HARDLINK
+                    || $fio->{protocol_version} < 27
+                    || $a->{hlink_self}) ) {
+        #
+        # Fill in fake inode information so that the remote rsync
+        # can correctly create hardlinks.
+        #
+        $name =~ s/^\.?\/+//;
+        my($target, $inode);
+
+        if ( $type == BPC_FTYPE_HARDLINK ) {
+            my $fh = BackupPC::FileZIO->open($a->{fullPath}, 0,
+                                             $a->{compress});
+            if ( defined($fh) ) {
+                $fh->read(\$target,  65536);
+                $fh->close;
+                $target =~ s/^\.?\/+//;
+                if ( defined($fio->{hlinkFile2Num}{$target}) ) {
+                    $inode = $fio->{hlinkFile2Num}{$target};
+                } else {
+                    $inode = $fio->{fileListCnt};
+                    $fio->{hlinkFile2Num}{$target} = $inode;
+                }
+            } else {
+                $fio->log("$a->{fullPath}: can't open for hardlink");
+                $fio->{stats}{errorCnt}++;
+            }
+        } elsif ( $a->{hlink_self} ) {
+            if ( defined($fio->{hlinkFile2Num}{$name}) ) {
+                $inode = $fio->{hlinkFile2Num}{$name};
+            } else {
+                $inode = $fio->{fileListCnt};
+                $fio->{hlinkFile2Num}{$name} = $inode;
+            }
+        }
+        $inode = $fio->{fileListCnt} if ( !defined($inode) );
+        $fio->log("$name: setting inode to $inode");
+        $extraAttribs = {
+            %$extraAttribs,
+            dev   => 0,
+            inode => $inode,
+        };
     }
     my $f = {
-            name  => $n,
-            #dev   => 0,		# later, when we support hardlinks
-            #inode => 0,		# later, when we support hardlinks
-            mode  => $a->{mode},
-            uid   => $a->{uid},
-            gid   => $a->{gid},
-            mtime => $a->{mtime},
-            size  => $a->{size},
-	    %$extraAttribs,
+        name  => $n,
+        mode  => $a->{mode} & ~S_HLINK_TARGET,
+        uid   => $a->{uid},
+        gid   => $a->{gid},
+        mtime => $a->{mtime},
+        size  => $a->{size},
+        %$extraAttribs,
     };
+    my $logName = $f->{name};
+    from_to($f->{name}, "utf8", $fio->{clientCharset})
+                            if ( $fio->{clientCharset} ne "" );
     $fList->encode($f);
-    $f->{name} = "$fio->{xfer}{pathHdrDest}/$f->{name}";
-    $f->{name} =~ s{//+}{/}g;
+
+    $logName = "$fio->{xfer}{pathHdrDest}/$logName";
+    $logName =~ s{//+}{/}g;
+    $f->{name} = $logName;
     $fio->logFileAction("restore", $f) if ( $fio->{logLevel} >= 1 );
+
     &$outputFunc($fList->encodeData);
     #
     # Cumulate stats
     #
+    $fio->{fileListCnt}++;
     if ( $type != BPC_FTYPE_DIR ) {
 	$fio->{stats}{TotalFileCnt}++;
 	$fio->{stats}{TotalFileSize} += $a->{size};
@@ -1155,6 +1384,8 @@ sub fileListSend
     #
     $fio->log("fileListSend: sending file list: "
 	     . join(" ", @{$fio->{fileList}})) if ( $fio->{logLevel} >= 4 );
+    $fio->{fileListCnt} = 0;
+    $fio->{hlinkFile2Num} = {};
     foreach my $name ( @{$fio->{fileList}} ) {
 	$fio->{view}->find($fio->{xfer}{bkupSrcNum},
 			   $fio->{xfer}{bkupSrcShare},
