@@ -29,7 +29,7 @@
 #
 #========================================================================
 #
-# Version 2.1.2, released 5 Sep 2005.
+# Version 3.0.0, released 28 Jan 2007.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -38,6 +38,7 @@
 package BackupPC::Xfer::Smb;
 
 use strict;
+use Encode qw/from_to encode/;
 
 sub new
 {
@@ -111,12 +112,16 @@ sub start
 	$t->{fileIncludeHash} = {};
         if ( defined($conf->{BackupFilesOnly}{$t->{shareName}}) ) {
             foreach my $file ( @{$conf->{BackupFilesOnly}{$t->{shareName}}} ) {
+                $file = encode($conf->{ClientCharset}, $file)
+                            if ( $conf->{ClientCharset} ne "" );
 		push(@fileList, $file);
 		$t->{fileIncludeHash}{$file} = 1;
             }
         } elsif ( defined($conf->{BackupFilesExclude}{$t->{shareName}}) ) {
             foreach my $file ( @{$conf->{BackupFilesExclude}{$t->{shareName}}} )
             {
+                $file = encode($conf->{ClientCharset}, $file)
+                            if ( $conf->{ClientCharset} ne "" );
 		push(@fileList, $file);
             }
 	    #
@@ -130,11 +135,13 @@ sub start
         } else {
             $timeStampFile = "$t->{outDir}/timeStamp.level0";
             open(LEV0, ">", $timeStampFile) && close(LEV0);
-            utime($t->{lastFull} - 3600, $t->{lastFull} - 3600, $timeStampFile);
+            utime($t->{incrBaseTime} - 3600, $t->{incrBaseTime} - 3600,
+                  $timeStampFile);
 	    $smbClientCmd = $conf->{SmbClientIncrCmd};
             $logMsg = "incr backup started back to "
-                        . $bpc->timeStamp($t->{lastFull} - 3600, 0)
-                        . "for share $t->{shareName}";
+                    . $bpc->timeStamp($t->{incrBaseTime} - 3600, 0)
+                    . " (backup #$t->{incrBaseBkupNum}) for share"
+                    . " $t->{shareName}";
         }
     }
     my $args = {
@@ -149,6 +156,8 @@ sub start
 	X_option      => $X_option,
 	timeStampFile => $timeStampFile,
     };
+    from_to($args->{shareName}, "utf8", $conf->{ClientCharset})
+                            if ( $conf->{ClientCharset} ne "" );
     $smbClientCmd = $bpc->cmdVarSubstitute($smbClientCmd, $args);
 
     if ( !defined($t->{xferPid} = open(SMB, "-|")) ) {
@@ -191,6 +200,8 @@ sub start
         return;
     }
     my $str = "Running: " . $bpc->execCmd2ShellCmd(@$smbClientCmd) . "\n";
+    from_to($str, $conf->{ClientCharset}, "utf8")
+                            if ( $conf->{ClientCharset} ne "" );
     $t->{XferLOG}->write(\$str);
     alarm($conf->{ClientTimeout});
     $t->{_errStr} = undef;
@@ -227,6 +238,9 @@ sub readOutput
         #
         alarm($conf->{ClientTimeout}) if ( !$t->{abort} );
         $t->{lastOutputLine} = $_ if ( !/^$/ );
+
+        from_to($_, $conf->{ClientCharset}, "utf8")
+                            if ( $conf->{ClientCharset} ne "" );
         #
         # This section is highly dependent on the version of smbclient.
         # If you upgrade Samba, make sure that these regexp are still valid.
@@ -261,6 +275,7 @@ sub readOutput
                     || /^\s*Call timed out: server did not respond/i
 		    || /^\s*tree connect failed: ERRDOS - ERRnoaccess \(Access denied\.\)/
 		    || /^\s*tree connect failed: NT_STATUS_BAD_NETWORK_NAME/
+		    || /^\s*NT_STATUS_INSUFF_SERVER_RESOURCES listing /
                  ) {
 	    if ( $t->{hostError} eq "" ) {
 		$t->{XferLOG}->write(\"This backup will fail because: $_\n");
